/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */
 
package org.ow2.weblab.core.model.processing;

import java.net.URI;
import java.util.Date;
import org.ow2.weblab.rdf.Value;
import org.ow2.weblab.core.model.*;
import org.ow2.weblab.core.annotator.*;

 /**
  * WebLab Exchange model used for resources processing v0.4.
  * 
  *  This version includes relationships used for WebLab Resources processing.
  * 
  *  WEBLAB: Service oriented
  *  integration platform for media mining and intelligence applications Copyright (C) 2004 - 2011 Cassidian, an EADS company
  */
public class WProcessingAnnotator extends BaseAnnotator {

	protected static final String APREFIX = "wp";
	protected static final URI AURI = URI.create("http://weblab.ow2.org/core/1.2/ontology/processing#");

	public WProcessingAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge){
		super(subject,pieceOfKnowledge);
	}

	public WProcessingAnnotator(Resource resource){
		super(resource);
	}

	protected static final String IS_LOCATED_AT = "isLocatedAt";
	protected static final String IS_SYNTHESIS_OF = "isSynthesisOf";
	protected static final String IS_DELIMITER_OF_SUMMARY_UNIT = "isDelimiterOfSummaryUnit";
	protected static final String HAS_CLUSTER_PROXIMITY = "hasClusterProximity";
	protected static final String IS_DELIMITER_OF_TRANSCRIPT_UNIT = "isDelimiterOfTranscriptUnit";
	protected static final String IS_FRAME_OF = "isFrameOf";
	protected static final String IS_DELIMITER_OF_RECOGNITION_UNIT = "isDelimiterOfRecognitionUnit";
	protected static final String IS_DELIMITER_OF_FRAME_UNIT = "isDelimiterOfFrameUnit";
	protected static final String IS_RECOGNITION_OF = "isRecognitionOf";
	protected static final String HAS_NORMALISED_CONTENT = "hasNormalisedContent";
	protected static final String IS_PRODUCED_BY = "isProducedBy";
	protected static final String IS_SHOT_OF = "isShotOf";
	protected static final String IS_DELIMITER_OF = "isDelimiterOf";
	protected static final String HAS_ORIGINAL_FILE_SIZE = "hasOriginalFileSize";
	protected static final String HAS_BEEN_UPDATED_BY = "hasBeenUpdatedBy";
	protected static final String IS_IN_CLUSTER = "isInCluster";
	protected static final String IS_DELIMITER_OF_SHOT_UNIT = "isDelimiterOfShotUnit";
	protected static final String IS_COMPOSED_BY_CLUSTER = "isComposedByCluster";
	protected static final String IS_IN_CLUSTER_LINK = "isInClusterLink";
	protected static final String IS_GENERATED_FROM = "isGeneratedFrom";
	protected static final String IS_SUMMARY_OF = "isSummaryOf";
	protected static final String IS_DELIMITER_OF_TRANSLATION_UNIT = "isDelimiterOfTranslationUnit";
	protected static final String REFERS_TO = "refersTo";
	protected static final String HAS_ORIGINAL_FILE_NAME = "hasOriginalFileName";
	protected static final String IS_DELIMITER_OF_SOUNDTRACK_UNIT = "isDelimiterOfSoundtrackUnit";
	protected static final String IS_TRANSLATION_OF = "isTranslationOf";
	protected static final String CAN_BE_IGNORED = "canBeIgnored";
	protected static final String IS_SOUNDTRACK_OF = "isSoundtrackOf";
	protected static final String IS_CLEANSING_OF = "isCleansingOf";
	protected static final String IS_EXPOSED_AS = "isExposedAs";
	protected static final String IS_EXPOSED_AS_THUMBNAIL = "isExposedAsThumbnail";
	protected static final String IS_CANDIDATE = "isCandidate";
	protected static final String IS_DELIMITER_OF_CLEANSING_UNIT = "isDelimiterOfCleansingUnit";
	protected static final String IS_TRANSCRIPT_OF = "isTranscriptOf";
	protected static final String HAS_GATHERING_DATE = "hasGatheringDate";
	protected static final String HAS_NATIVE_CONTENT = "hasNativeContent";
	protected static final String IS_DELIMITER_OF_SYNTHESIS_UNIT = "isDelimiterOfSynthesisUnit";

	/**
	 * Read the Links a MediaUnit to the segment from which it has been produced. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLocatedAt(){
		return applyOperator(Operator.READ, null,AURI, IS_LOCATED_AT, URI.class, null);
	}


	/**
	 * Write the Links a MediaUnit to the segment from which it has been produced.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLocatedAt(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_LOCATED_AT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a synthesized Audio unit to its source Text. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readSynthesisOf(){
		return applyOperator(Operator.READ, null,AURI, IS_SYNTHESIS_OF, URI.class, null);
	}


	/**
	 * Write the Links a synthesized Audio unit to its source Text.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeSynthesisOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_SYNTHESIS_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the summary MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfSummaryUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_SUMMARY_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the summary MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfSummaryUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_SUMMARY_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Value that corresponds to the proximity between the two clusters implied in a cluster link. 
	 * 
	 * @return a Double
	 */
	public Value<Double> readClusterProximity(){
		return applyOperator(Operator.READ, null,AURI, HAS_CLUSTER_PROXIMITY, Double.class, null);
	}


	/**
	 * Write the Value that corresponds to the proximity between the two clusters implied in a cluster link.
	 * @param value a Double
	 */
	public PieceOfKnowledge writeClusterProximity(Double value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CLUSTER_PROXIMITY, Double.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the transcript MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfTranscriptUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_TRANSCRIPT_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the transcript MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfTranscriptUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_TRANSCRIPT_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a frame Image to its source Video. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readFrameOf(){
		return applyOperator(Operator.READ, null,AURI, IS_FRAME_OF, URI.class, null);
	}


	/**
	 * Write the Links a frame Image to its source Video.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeFrameOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_FRAME_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the recognition MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfRecognitionUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_RECOGNITION_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the recognition MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfRecognitionUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_RECOGNITION_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the frame MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfFrameUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_FRAME_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the frame MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfFrameUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_FRAME_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links an extracted Text to its source Image. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRecognitionOf(){
		return applyOperator(Operator.READ, null,AURI, IS_RECOGNITION_OF, URI.class, null);
	}


	/**
	 * Write the Links an extracted Text to its source Image.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRecognitionOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_RECOGNITION_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a media unit to its normalised content. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readNormalisedContent(){
		return applyOperator(Operator.READ, null,AURI, HAS_NORMALISED_CONTENT, URI.class, null);
	}


	/**
	 * Write the Links a media unit to its normalised content.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeNormalisedContent(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_NORMALISED_CONTENT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Indicates the service that has produced automatically or semi-automatically the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readProducedBy(){
		return applyOperator(Operator.READ, null,AURI, IS_PRODUCED_BY, URI.class, null);
	}


	/**
	 * Write the Indicates the service that has produced automatically or semi-automatically the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeProducedBy(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_PRODUCED_BY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a shot Video to its source Video. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readShotOf(){
		return applyOperator(Operator.READ, null,AURI, IS_SHOT_OF, URI.class, null);
	}


	/**
	 * Write the Links a shot Video to its source Video.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeShotOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_SHOT_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOf(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF, URI.class, null);
	}


	/**
	 * Write the Links a segment to the MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the number of bytes of the original file gathered. 
	 * 
	 * @return a Long
	 */
	public Value<Long> readOriginalFileSize(){
		return applyOperator(Operator.READ, null,AURI, HAS_ORIGINAL_FILE_SIZE, Long.class, null);
	}


	/**
	 * Write the Gives the number of bytes of the original file gathered.
	 * @param value a Long
	 */
	public PieceOfKnowledge writeOriginalFileSize(Long value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_ORIGINAL_FILE_SIZE, Long.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a resource to the service that has modified this resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readBeenUpdatedBy(){
		return applyOperator(Operator.READ, null,AURI, HAS_BEEN_UPDATED_BY, URI.class, null);
	}


	/**
	 * Write the Links a resource to the service that has modified this resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeBeenUpdatedBy(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_BEEN_UPDATED_BY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a WebLab Document to a Cluster. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInCluster(){
		return applyOperator(Operator.READ, null,AURI, IS_IN_CLUSTER, URI.class, null);
	}


	/**
	 * Write the Links a WebLab Document to a Cluster.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeInCluster(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_IN_CLUSTER, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the shot MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfShotUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_SHOT_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the shot MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfShotUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_SHOT_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Link a ClusterLink with its two components clusters. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readComposedByCluster(){
		return applyOperator(Operator.READ, null,AURI, IS_COMPOSED_BY_CLUSTER, URI.class, null);
	}


	/**
	 * Write the Link a ClusterLink with its two components clusters.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeComposedByCluster(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_COMPOSED_BY_CLUSTER, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a cluster to a ClusterLink. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInClusterLink(){
		return applyOperator(Operator.READ, null,AURI, IS_IN_CLUSTER_LINK, URI.class, null);
	}


	/**
	 * Write the Links a cluster to a ClusterLink.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeInClusterLink(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_IN_CLUSTER_LINK, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a resource or segment result of an automatic (translation, summarisation, transcription) process to its source resource or segment. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readGeneratedFrom(){
		return applyOperator(Operator.READ, null,AURI, IS_GENERATED_FROM, URI.class, null);
	}


	/**
	 * Write the Links a resource or segment result of an automatic (translation, summarisation, transcription) process to its source resource or segment.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeGeneratedFrom(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_GENERATED_FROM, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a summary to its source Text. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readSummaryOf(){
		return applyOperator(Operator.READ, null,AURI, IS_SUMMARY_OF, URI.class, null);
	}


	/**
	 * Write the Links a summary to its source Text.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeSummaryOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_SUMMARY_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the translation MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfTranslationUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_TRANSLATION_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the translation MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfTranslationUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_TRANSLATION_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to an instance of a recognised entity (given its URI). 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRefersTo(){
		return applyOperator(Operator.READ, null,AURI, REFERS_TO, URI.class, null);
	}


	/**
	 * Write the Links a segment to an instance of a recognised entity (given its URI).
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRefersTo(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, REFERS_TO, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the name of the original file gathered. 
	 * 
	 * @return a String
	 */
	public Value<String> readOriginalFileName(){
		return applyOperator(Operator.READ, null,AURI, HAS_ORIGINAL_FILE_NAME, String.class, null);
	}


	/**
	 * Write the Gives the name of the original file gathered.
	 * @param value a String
	 */
	public PieceOfKnowledge writeOriginalFileName(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_ORIGINAL_FILE_NAME, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the soundtrack MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfSoundtrackUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_SOUNDTRACK_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the soundtrack MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfSoundtrackUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_SOUNDTRACK_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links translated Text or LinearSegment to its source Text or LinearSegment. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readTranslationOf(){
		return applyOperator(Operator.READ, null,AURI, IS_TRANSLATION_OF, URI.class, null);
	}


	/**
	 * Write the Links translated Text or LinearSegment to its source Text or LinearSegment.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeTranslationOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_TRANSLATION_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Indicates whether or not a MediaUnit can be ignored by a service. 
	 * 
	 * @return a Boolean
	 */
	public Value<Boolean> readCanBeIgnored(){
		return applyOperator(Operator.READ, null,AURI, CAN_BE_IGNORED, Boolean.class, null);
	}


	/**
	 * Write the Indicates whether or not a MediaUnit can be ignored by a service.
	 * @param value a Boolean
	 */
	public PieceOfKnowledge writeCanBeIgnored(Boolean value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, CAN_BE_IGNORED, Boolean.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a soundtrack to its source Video. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readSoundtrackOf(){
		return applyOperator(Operator.READ, null,AURI, IS_SOUNDTRACK_OF, URI.class, null);
	}


	/**
	 * Write the Links a soundtrack to its source Video.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeSoundtrackOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_SOUNDTRACK_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a cleansed MediaUnit to its source MediaUnit. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readCleansingOf(){
		return applyOperator(Operator.READ, null,AURI, IS_CLEANSING_OF, URI.class, null);
	}


	/**
	 * Write the Links a cleansed MediaUnit to its source MediaUnit.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeCleansingOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_CLEANSING_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Is exposed on a given protocol at a given address (for instance points to an
	 *  URL). 
	 * 
	 * @return a String
	 */
	public Value<String> readExposedAs(){
		return applyOperator(Operator.READ, null,AURI, IS_EXPOSED_AS, String.class, null);
	}


	/**
	 * Write the Is exposed on a given protocol at a given address (for instance points to an
	 *  URL).
	 * @param value a String
	 */
	public PieceOfKnowledge writeExposedAs(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_EXPOSED_AS, String.class, value).getIsAnnotatedOn();
	}

	/**
	 * Read the exposed as a given thumbnail at a given address (for instance points to an
	 *  URL). 
	 * 
	 * @return a String
	 */
	public Value<String> readExposedAsThumbnail(){
		return applyOperator(Operator.READ, null,AURI, IS_EXPOSED_AS_THUMBNAIL, String.class, null);
	}


	/**
	 * Write the exposed as a given thumbnail at a given address (for instance points to an
	 *  URL).
	 * @param value a String
	 */
	public PieceOfKnowledge writeExposedAsThumbnail(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_EXPOSED_AS_THUMBNAIL, String.class, value).getIsAnnotatedOn();
	}
	

	/**
	 * Read the Indicates whether or not is the instance extracted a candidate instance. 
	 * 
	 * @return a Boolean
	 */
	public Value<Boolean> readCandidate(){
		return applyOperator(Operator.READ, null,AURI, IS_CANDIDATE, Boolean.class, null);
	}


	/**
	 * Write the Indicates whether or not is the instance extracted a candidate instance.
	 * @param value a Boolean
	 */
	public PieceOfKnowledge writeCandidate(Boolean value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_CANDIDATE, Boolean.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the cleansing MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfCleansingUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_CLEANSING_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the cleansing MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfCleansingUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_CLEANSING_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a transcript to its source (Image or Video MediaUnit). 
	 * 
	 * @return an URI
	 */
	public Value<URI> readTranscriptOf(){
		return applyOperator(Operator.READ, null,AURI, IS_TRANSCRIPT_OF, URI.class, null);
	}


	/**
	 * Write the Links a transcript to its source (Image or Video MediaUnit).
	 * @param value an URI
	 */
	public PieceOfKnowledge writeTranscriptOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_TRANSCRIPT_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the date when the Document was gathered. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readGatheringDate(){
		return applyOperator(Operator.READ, null,AURI, HAS_GATHERING_DATE, Date.class, null);
	}


	/**
	 * Write the Gives the date when the Document was gathered.
	 * @param value a Date
	 */
	public PieceOfKnowledge writeGatheringDate(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_GATHERING_DATE, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a media unit to its native content. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readNativeContent(){
		return applyOperator(Operator.READ, null,AURI, HAS_NATIVE_CONTENT, URI.class, null);
	}


	/**
	 * Write the Links a media unit to its native content.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeNativeContent(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_NATIVE_CONTENT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the synthesis MediaUnit it represents. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDelimiterOfSynthesisUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_DELIMITER_OF_SYNTHESIS_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the synthesis MediaUnit it represents.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDelimiterOfSynthesisUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_DELIMITER_OF_SYNTHESIS_UNIT, URI.class, value).getIsAnnotatedOn();
	}



}

