/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */
package org.ow2.weblab.core.model.retrieval;

import java.net.URI;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;

 /**
  * WebLab Exchange model used for resources retrieval v0.4
  * 
  *  This version includes relationships used for WebLab Resources retrieval.
  * 
  *  WEBLAB: Service oriented integration platform for media mining and intelligence applications Copyright (C) 2004 - 2011 Cassidian, an EADS company
  */
public class WRetrievalAnnotator extends BaseAnnotator {

	protected static final String APREFIX = "wrt";
	protected static final URI AURI = URI.create("http://weblab.ow2.org/core/1.2/ontology/retrieval#");

	public WRetrievalAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge){
		super(subject,pieceOfKnowledge);
	}

	public WRetrievalAnnotator(Resource resource){
		super(resource);
	}

	protected static final String HAS_ORDERED_QUERY = "hasOrderedQuery";
	protected static final String HAS_RANK = "hasRank";
	protected static final String HAS_QUERY_OFFSET = "hasQueryOffset";
	protected static final String HAS_EXPECTED_OFFSET = "hasExpectedOffset";
	protected static final String HAS_HIT = "hasHit";
	protected static final String IN_RESULT_SET_HIT = "inResultSetHit";
	protected static final String IS_RESULT_OF = "isResultOf";
	protected static final String HAS_SCORE = "hasScore";
	protected static final String HAS_DESCRIPTION = "hasDescription";
	protected static final String IS_LINKED_TO = "isLinkedTo";
	protected static final String HAS_EXPECTED_LIMIT = "hasExpectedLimit";
	protected static final String HAS_NUMBER_OF_RESULTS = "hasNumberOfResults";
	protected static final String IS_EXPRESSED_WITH = "isExpressedWith";

	/**
	 * Read the Gives a link to the requested query for this order. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readOrderedQuery(){
		return applyOperator(Operator.READ, null,AURI, HAS_ORDERED_QUERY, URI.class, null);
	}


	/**
	 * Write the Gives a link to the requested query for this order.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeOrderedQuery(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_ORDERED_QUERY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives a rank for hit. 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readRank(){
		return applyOperator(Operator.READ, null,AURI, HAS_RANK, Integer.class, null);
	}


	/**
	 * Write the Gives a rank for hit.
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeRank(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_RANK, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Provides the offset about the query in the case of a result set returns by a search service. 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readQueryOffset(){
		return applyOperator(Operator.READ, null,AURI, HAS_QUERY_OFFSET, Integer.class, null);
	}


	/**
	 * Write the Provides the offset about the query in the case of a result set returns by a search service.
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeQueryOffset(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_QUERY_OFFSET, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the expected offset for the requested query for this order. 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readExpectedOffset(){
		return applyOperator(Operator.READ, null,AURI, HAS_EXPECTED_OFFSET, Integer.class, null);
	}


	/**
	 * Write the Gives the expected offset for the requested query for this order.
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeExpectedOffset(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_EXPECTED_OFFSET, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives a hit for ResultSet. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readHit(){
		return applyOperator(Operator.READ, null,AURI, HAS_HIT, URI.class, null);
	}


	/**
	 * Write the Gives a hit for ResultSet.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeHit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_HIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a Hit to its ResultSet. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInResultSetHit(){
		return applyOperator(Operator.READ, null,AURI, IN_RESULT_SET_HIT, URI.class, null);
	}


	/**
	 * Write the Links a Hit to its ResultSet.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeInResultSetHit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IN_RESULT_SET_HIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a ResultSet to the Query that has been used to retrieve the set of results. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readResultOf(){
		return applyOperator(Operator.READ, null,AURI, IS_RESULT_OF, URI.class, null);
	}


	/**
	 * Write the Links a ResultSet to the Query that has been used to retrieve the set of results.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeResultOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_RESULT_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives a score for hit. 
	 * 
	 * @return a Double
	 */
	public Value<Double> readScore(){
		return applyOperator(Operator.READ, null,AURI, HAS_SCORE, Double.class, null);
	}


	/**
	 * Write the Gives a score for hit.
	 * @param value a Double
	 */
	public PieceOfKnowledge writeScore(Double value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_SCORE, Double.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives a description for a hit. 
	 * 
	 * @return a String
	 */
	public Value<String> readDescription(){
		return applyOperator(Operator.READ, null,AURI, HAS_DESCRIPTION, String.class, null);
	}


	/**
	 * Write the Gives a description for a hit.
	 * @param value a String
	 */
	public PieceOfKnowledge writeDescription(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_DESCRIPTION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives a link to resource for hit. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLinkedTo(){
		return applyOperator(Operator.READ, null,AURI, IS_LINKED_TO, URI.class, null);
	}


	/**
	 * Write the Gives a link to resource for hit.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLinkedTo(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_LINKED_TO, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the limit for the requested query for this order. 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readExpectedLimit(){
		return applyOperator(Operator.READ, null,AURI, HAS_EXPECTED_LIMIT, Integer.class, null);
	}


	/**
	 * Write the Gives the limit for the requested query for this order.
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeExpectedLimit(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_EXPECTED_LIMIT, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the total number of results for this result set. 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readNumberOfResults(){
		return applyOperator(Operator.READ, null,AURI, HAS_NUMBER_OF_RESULTS, Integer.class, null);
	}


	/**
	 * Write the Gives the total number of results for this result set.
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeNumberOfResults(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_NUMBER_OF_RESULTS, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the language of the query . 
	 * 
	 * @return a String
	 */
	public Value<String> readExpressedWith(){
		return applyOperator(Operator.READ, null,AURI, IS_EXPRESSED_WITH, String.class, null);
	}


	/**
	 * Write the Gives the language of the query .
	 * @param value a String
	 */
	public PieceOfKnowledge writeExpressedWith(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_EXPRESSED_WITH, String.class, value).getIsAnnotatedOn();
	}



}

