/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

package org.w3.owl;

import java.net.URI;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;
import org.ow2.weblab.rdf.XMLParser;

public class OWLAnnotator extends BaseAnnotator {

	protected static final String PREFIX = "owl";
	protected static final URI URI = XMLParser.buildURI("http://www.w3.org/2002/07/owl#");

	protected static final String OWL = "owl";
	protected static final String BOTTOM_DATA_PROPERTY = "bottomDataProperty";
	protected static final String TOP_DATA_PROPERTY = "topDataProperty";
	protected static final String BOTTOM = "bottom";
	protected static final String TOP = "top";
	protected static final String ALL_VALUES_FROM = "allValuesFrom";
	protected static final String ANNOTATED_PROPERTY = "annotatedProperty";
	protected static final String ANNOTATED_SOURCE = "annotatedSource";
	protected static final String ANNOTATED_TARGET = "annotatedTarget";
	protected static final String ASSERTION_PROPERTY = "assertionProperty";
	protected static final String CARDINALITY = "cardinality";
	protected static final String COMPLEMENT_OF = "complementOf";
	protected static final String DATATYPE_COMPLEMENT_OF = "datatypeComplementOf";
	protected static final String DIFFERENT_FROM = "differentFrom";
	protected static final String DISJOINT_UNION_OF = "disjointUnionOf";
	protected static final String DISJOINT_WITH = "disjointWith";
	protected static final String DISTINCT_MEMBERS = "distinctMembers";
	protected static final String EQUIVALENT_CLASS = "equivalentClass";
	protected static final String EQUIVALENT_PROPERTY = "equivalentProperty";
	protected static final String HAS_KEY = "hasKey";
	protected static final String HAS_SELF = "hasSelf";
	protected static final String HAS_VALUE = "hasValue";
	protected static final String INTERSECTION_OF = "intersectionOf";
	protected static final String INVERSE_OF = "inverseOf";
	protected static final String MAX_CARDINALITY = "maxCardinality";
	protected static final String MAX_QUALIFIED_CARDINALITY = "maxQualifiedCardinality";
	protected static final String MEMBERS = "members";
	protected static final String MIN_CARDINALITY = "minCardinality";
	protected static final String MIN_QUALIFIED_CARDINALITY = "minQualifiedCardinality";
	protected static final String ON_CLASS = "onClass";
	protected static final String ON_DATA_RANGE = "onDataRange";
	protected static final String ON_DATATYPE = "onDatatype";
	protected static final String ONE_OF = "oneOf";
	protected static final String ON_PROPERTIES = "onProperties";
	protected static final String ON_PROPERTY = "onProperty";
	protected static final String PROPERTY_CHAIN_AXIOM = "propertyChainAxiom";
	protected static final String PROPERTY_DISJOINT_WITH = "propertyDisjointWith";
	protected static final String QUALIFIED_CARDINALITY = "qualifiedCardinality";
	protected static final String SAME_AS = "sameAs";
	protected static final String SOME_VALUES_FROM = "someValuesFrom";
	protected static final String SOURCE_INDIVIDUAL = "sourceIndividual";
	protected static final String TARGET_INDIVIDUAL = "targetIndividual";
	protected static final String TARGET_VALUE = "targetValue";
	protected static final String UNION_OF = "unionOf";
	protected static final String WITH_RESTRICTIONS = "withRestrictions";
	
	
	public OWLAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge) {
		super(subject, pieceOfKnowledge);
	}

	public OWLAnnotator(Resource resource) {
		super(resource);
	}

	/**
	 * Read the
	 * 
	 * @return an URI
	 */
	public Value<URI> readOwl() {
		return applyOperator(Operator.READ, null, URI, OWL, URI.class, null);
	}


	/**
	 * Write the
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeOwl(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, OWL, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The data property that does not relate any individual to any data value.
	 * 
	 * @return a String
	 */
	public Value<String> readBottomDataProperty() {
		return applyOperator(Operator.READ, null, URI, BOTTOM_DATA_PROPERTY, String.class, null);
	}


	/**
	 * Write the The data property that does not relate any individual to any data value.
	 * 
	 * @param value
	 *            a String
	 */
	public PieceOfKnowledge writeBottomDataProperty(String value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, BOTTOM_DATA_PROPERTY, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The data property that relates every individual to every data value.
	 * 
	 * @return a String
	 */
	public Value<String> readTopDataProperty() {
		return applyOperator(Operator.READ, null, URI, TOP_DATA_PROPERTY, String.class, null);
	}


	/**
	 * Write the The data property that relates every individual to every data value.
	 * 
	 * @param value
	 *            a String
	 */
	public PieceOfKnowledge writeTopDataProperty(String value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, TOP_DATA_PROPERTY, String.class, value).getIsAnnotatedOn();
	}



	/**
	 * Read the The object property that does not relate any two individuals.
	 * 
	 * @return a String
	 */
	public Value<String> readBottom() {
		return applyOperator(Operator.READ, null, URI, BOTTOM, String.class, null);
	}


	/**
	 * Write the The object property that does not relate any two individuals.
	 * 
	 * @param value
	 *            a String
	 */
	public PieceOfKnowledge writeBottom(String value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, BOTTOM, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The object property that relates every two individuals.
	 * 
	 * @return a String
	 */
	public Value<String> readTop() {
		return applyOperator(Operator.READ, null, URI, TOP, String.class, null);
	}


	/**
	 * Write the The object property that relates every two individuals.
	 * 
	 * @param value
	 *            a String
	 */
	public PieceOfKnowledge writeTop(String value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, TOP, String.class, value).getIsAnnotatedOn();
	}



	/**
	 * Read the The property that determines the class that a universal property restriction refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readAllValuesFrom() {
		return applyOperator(Operator.READ, null, URI, ALL_VALUES_FROM, URI.class, null);
	}


	/**
	 * Write the The property that determines the class that a universal property restriction refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeAllValuesFrom(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ALL_VALUES_FROM, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the predicate of an annotated axiom or annotated annotation.
	 * 
	 * @return an URI
	 */
	public Value<URI> readAnnotatedProperty() {
		return applyOperator(Operator.READ, null, URI, ANNOTATED_PROPERTY, URI.class, null);
	}


	/**
	 * Write the The property that determines the predicate of an annotated axiom or annotated annotation.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeAnnotatedProperty(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ANNOTATED_PROPERTY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the subject of an annotated axiom or annotated annotation.
	 * 
	 * @return an URI
	 */
	public Value<URI> readAnnotatedSource() {
		return applyOperator(Operator.READ, null, URI, ANNOTATED_SOURCE, URI.class, null);
	}


	/**
	 * Write the The property that determines the subject of an annotated axiom or annotated annotation.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeAnnotatedSource(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ANNOTATED_SOURCE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the object of an annotated axiom or annotated annotation.
	 * 
	 * @return an URI
	 */
	public Value<URI> readAnnotatedTarget() {
		return applyOperator(Operator.READ, null, URI, ANNOTATED_TARGET, URI.class, null);
	}


	/**
	 * Write the The property that determines the object of an annotated axiom or annotated annotation.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeAnnotatedTarget(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ANNOTATED_TARGET, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the predicate of a negative property assertion.
	 * 
	 * @return an URI
	 */
	public Value<URI> readAssertionProperty() {
		return applyOperator(Operator.READ, null, URI, ASSERTION_PROPERTY, URI.class, null);
	}


	/**
	 * Write the The property that determines the predicate of a negative property assertion.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeAssertionProperty(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ASSERTION_PROPERTY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the cardinality of an exact cardinality restriction.
	 * 
	 * @return an URI
	 */
	public Value<URI> readCardinality() {
		return applyOperator(Operator.READ, null, URI, CARDINALITY, URI.class, null);
	}


	/**
	 * Write the The property that determines the cardinality of an exact cardinality restriction.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeCardinality(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, CARDINALITY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that a given class is the complement of another class.
	 * 
	 * @return an URI
	 */
	public Value<URI> readComplementOf() {
		return applyOperator(Operator.READ, null, URI, COMPLEMENT_OF, URI.class, null);
	}


	/**
	 * Write the The property that determines that a given class is the complement of another class.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeComplementOf(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, COMPLEMENT_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that a given data range is the complement of another data range with respect to the data domain.
	 * 
	 * @return an URI
	 */
	public Value<URI> readDatatypeComplementOf() {
		return applyOperator(Operator.READ, null, URI, DATATYPE_COMPLEMENT_OF, URI.class, null);
	}


	/**
	 * Write the The property that determines that a given data range is the complement of another data range with respect to the data domain.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeDatatypeComplementOf(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, DATATYPE_COMPLEMENT_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that two given individuals are different.
	 * 
	 * @return a String
	 */
	public Value<String> readDifferentFrom() {
		return applyOperator(Operator.READ, null, URI, DIFFERENT_FROM, String.class, null);
	}


	/**
	 * Write the The property that determines that two given individuals are different.
	 * 
	 * @param value
	 *            a String
	 */
	public PieceOfKnowledge writeDifferentFrom(String value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, DIFFERENT_FROM, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that a given class is equivalent to the disjoint union of a collection of other classes.
	 * 
	 * @return an URI
	 */
	public Value<URI> readDisjointUnionOf() {
		return applyOperator(Operator.READ, null, URI, DISJOINT_UNION_OF, URI.class, null);
	}


	/**
	 * Write the The property that determines that a given class is equivalent to the disjoint union of a collection of other classes.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeDisjointUnionOf(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, DISJOINT_UNION_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that two given classes are disjoint.
	 * 
	 * @return an URI
	 */
	public Value<URI> readDisjointWith() {
		return applyOperator(Operator.READ, null, URI, DISJOINT_WITH, URI.class, null);
	}


	/**
	 * Write the The property that determines that two given classes are disjoint.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeDisjointWith(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, DISJOINT_WITH, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the collection of pairwise different individuals in a owl:AllDifferent axiom.
	 * 
	 * @return an URI
	 */
	public Value<URI> readDistinctMembers() {
		return applyOperator(Operator.READ, null, URI, DISTINCT_MEMBERS, URI.class, null);
	}


	/**
	 * Write the The property that determines the collection of pairwise different individuals in a owl:AllDifferent axiom.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeDistinctMembers(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, DISTINCT_MEMBERS, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that two given classes are equivalent, and that is used to specify datatype definitions.
	 * 
	 * @return an URI
	 */
	public Value<URI> readEquivalentClass() {
		return applyOperator(Operator.READ, null, URI, EQUIVALENT_CLASS, URI.class, null);
	}


	/**
	 * Write the The property that determines that two given classes are equivalent, and that is used to specify datatype definitions.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeEquivalentClass(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, EQUIVALENT_CLASS, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that two given properties are equivalent.
	 * 
	 * @return an URI
	 */
	public Value<URI> readEquivalentProperty() {
		return applyOperator(Operator.READ, null, URI, EQUIVALENT_PROPERTY, URI.class, null);
	}


	/**
	 * Write the The property that determines that two given properties are equivalent.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeEquivalentProperty(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, EQUIVALENT_PROPERTY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the collection of properties that jointly build a key.
	 * 
	 * @return an URI
	 */
	public Value<URI> readHasKey() {
		return applyOperator(Operator.READ, null, URI, HAS_KEY, URI.class, null);
	}


	/**
	 * Write the The property that determines the collection of properties that jointly build a key.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeHasKey(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, HAS_KEY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the property that a self restriction refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readHasSelf() {
		return applyOperator(Operator.READ, null, URI, HAS_SELF, URI.class, null);
	}


	/**
	 * Write the The property that determines the property that a self restriction refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeHasSelf(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, HAS_SELF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the individual that a has-value restriction refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readHasValue() {
		return applyOperator(Operator.READ, null, URI, HAS_VALUE, URI.class, null);
	}


	/**
	 * Write the The property that determines the individual that a has-value restriction refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeHasValue(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, HAS_VALUE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the collection of classes or data ranges that build an intersection.
	 * 
	 * @return an URI
	 */
	public Value<URI> readIntersectionOf() {
		return applyOperator(Operator.READ, null, URI, INTERSECTION_OF, URI.class, null);
	}


	/**
	 * Write the The property that determines the collection of classes or data ranges that build an intersection.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeIntersectionOf(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, INTERSECTION_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that two given properties are inverse.
	 * 
	 * @return an URI
	 */
	public Value<URI> readInverseOf() {
		return applyOperator(Operator.READ, null, URI, INVERSE_OF, URI.class, null);
	}


	/**
	 * Write the The property that determines that two given properties are inverse.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeInverseOf(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, INVERSE_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the cardinality of a maximum cardinality restriction.
	 * 
	 * @return an URI
	 */
	public Value<URI> readMaxCardinality() {
		return applyOperator(Operator.READ, null, URI, MAX_CARDINALITY, URI.class, null);
	}


	/**
	 * Write the The property that determines the cardinality of a maximum cardinality restriction.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeMaxCardinality(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, MAX_CARDINALITY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the cardinality of a maximum qualified cardinality restriction.
	 * 
	 * @return an URI
	 */
	public Value<URI> readMaxQualifiedCardinality() {
		return applyOperator(Operator.READ, null, URI, MAX_QUALIFIED_CARDINALITY, URI.class, null);
	}


	/**
	 * Write the The property that determines the cardinality of a maximum qualified cardinality restriction.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeMaxQualifiedCardinality(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, MAX_QUALIFIED_CARDINALITY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the collection of members in either a owl:AllDifferent, :AllDisjointClasses or owl:AllDisjointProperties axiom.
	 * 
	 * @return an URI
	 */
	public Value<URI> readMembers() {
		return applyOperator(Operator.READ, null, URI, MEMBERS, URI.class, null);
	}


	/**
	 * Write the The property that determines the collection of members in either a owl:AllDifferent, :AllDisjointClasses or owl:AllDisjointProperties axiom.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeMembers(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, MEMBERS, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the cardinality of a minimum cardinality restriction.
	 * 
	 * @return an URI
	 */
	public Value<URI> readMinCardinality() {
		return applyOperator(Operator.READ, null, URI, MIN_CARDINALITY, URI.class, null);
	}


	/**
	 * Write the The property that determines the cardinality of a minimum cardinality restriction.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeMinCardinality(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, MIN_CARDINALITY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the cardinality of a minimum qualified cardinality restriction.
	 * 
	 * @return an URI
	 */
	public Value<URI> readMinQualifiedCardinality() {
		return applyOperator(Operator.READ, null, URI, MIN_QUALIFIED_CARDINALITY, URI.class, null);
	}


	/**
	 * Write the The property that determines the cardinality of a minimum qualified cardinality restriction.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeMinQualifiedCardinality(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, MIN_QUALIFIED_CARDINALITY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the class that a qualified object cardinality restriction refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readOnClass() {
		return applyOperator(Operator.READ, null, URI, ON_CLASS, URI.class, null);
	}


	/**
	 * Write the The property that determines the class that a qualified object cardinality restriction refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeOnClass(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ON_CLASS, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the data range that a qualified data cardinality restriction refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readOnDataRange() {
		return applyOperator(Operator.READ, null, URI, ON_DATA_RANGE, URI.class, null);
	}


	/**
	 * Write the The property that determines the data range that a qualified data cardinality restriction refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeOnDataRange(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ON_DATA_RANGE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the datatype that a datatype restriction refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readOnDatatype() {
		return applyOperator(Operator.READ, null, URI, ON_DATATYPE, URI.class, null);
	}


	/**
	 * Write the The property that determines the datatype that a datatype restriction refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeOnDatatype(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ON_DATATYPE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the collection of individuals or data values that build an enumeration.
	 * 
	 * @return an URI
	 */
	public Value<URI> readOneOf() {
		return applyOperator(Operator.READ, null, URI, ONE_OF, URI.class, null);
	}


	/**
	 * Write the The property that determines the collection of individuals or data values that build an enumeration.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeOneOf(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ONE_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the n-tuple of properties that a property restriction on an n-ary data range refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readOnProperties() {
		return applyOperator(Operator.READ, null, URI, ON_PROPERTIES, URI.class, null);
	}


	/**
	 * Write the The property that determines the n-tuple of properties that a property restriction on an n-ary data range refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeOnProperties(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ON_PROPERTIES, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the property that a property restriction refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readOnProperty() {
		return applyOperator(Operator.READ, null, URI, ON_PROPERTY, URI.class, null);
	}


	/**
	 * Write the The property that determines the property that a property restriction refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeOnProperty(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, ON_PROPERTY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the n-tuple of properties that build a sub property chain of a given property.
	 * 
	 * @return an URI
	 */
	public Value<URI> readPropertyChainAxiom() {
		return applyOperator(Operator.READ, null, URI, PROPERTY_CHAIN_AXIOM, URI.class, null);
	}


	/**
	 * Write the The property that determines the n-tuple of properties that build a sub property chain of a given property.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writePropertyChainAxiom(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, PROPERTY_CHAIN_AXIOM, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that two given properties are disjoint.
	 * 
	 * @return an URI
	 */
	public Value<URI> readPropertyDisjointWith() {
		return applyOperator(Operator.READ, null, URI, PROPERTY_DISJOINT_WITH, URI.class, null);
	}


	/**
	 * Write the The property that determines that two given properties are disjoint.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writePropertyDisjointWith(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, PROPERTY_DISJOINT_WITH, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the cardinality of an exact qualified cardinality restriction.
	 * 
	 * @return an URI
	 */
	public Value<URI> readQualifiedCardinality() {
		return applyOperator(Operator.READ, null, URI, QUALIFIED_CARDINALITY, URI.class, null);
	}


	/**
	 * Write the The property that determines the cardinality of an exact qualified cardinality restriction.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeQualifiedCardinality(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, QUALIFIED_CARDINALITY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines that two given individuals are equal.
	 * 
	 * @return a URI
	 */
	public Value<URI> readSameAs() {
		return applyOperator(Operator.READ, null, URI, SAME_AS, URI.class, null);
	}


	/**
	 * Write the The property that determines that two given individuals are equal.
	 * 
	 * @param value
	 *            a URI
	 */
	public PieceOfKnowledge writeSameAs(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, SAME_AS, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the class that an existential property restriction refers to.
	 * 
	 * @return an URI
	 */
	public Value<URI> readSomeValuesFrom() {
		return applyOperator(Operator.READ, null, URI, SOME_VALUES_FROM, URI.class, null);
	}


	/**
	 * Write the The property that determines the class that an existential property restriction refers to.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeSomeValuesFrom(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, SOME_VALUES_FROM, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the subject of a negative property assertion.
	 * 
	 * @return a String
	 */
	public Value<String> readSourceIndividual() {
		return applyOperator(Operator.READ, null, URI, SOURCE_INDIVIDUAL, String.class, null);
	}


	/**
	 * Write the The property that determines the subject of a negative property assertion.
	 * 
	 * @param value
	 *            a String
	 */
	public PieceOfKnowledge writeSourceIndividual(String value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, SOURCE_INDIVIDUAL, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the object of a negative object property assertion.
	 * 
	 * @return a String
	 */
	public Value<String> readTargetIndividual() {
		return applyOperator(Operator.READ, null, URI, TARGET_INDIVIDUAL, String.class, null);
	}


	/**
	 * Write the The property that determines the object of a negative object property assertion.
	 * 
	 * @param value
	 *            a String
	 */
	public PieceOfKnowledge writeTargetIndividual(String value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, TARGET_INDIVIDUAL, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the value of a negative data property assertion.
	 * 
	 * @return a String
	 */
	public Value<String> readTargetValue() {
		return applyOperator(Operator.READ, null, URI, TARGET_VALUE, String.class, null);
	}


	/**
	 * Write the The property that determines the value of a negative data property assertion.
	 * 
	 * @param value
	 *            a String
	 */
	public PieceOfKnowledge writeTargetValue(String value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, TARGET_VALUE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the collection of classes or data ranges that build a union.
	 * 
	 * @return an URI
	 */
	public Value<URI> readUnionOf() {
		return applyOperator(Operator.READ, null, URI, UNION_OF, URI.class, null);
	}


	/**
	 * Write the The property that determines the collection of classes or data ranges that build a union.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeUnionOf(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, UNION_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The property that determines the collection of facet-value pairs that define a datatype restriction.
	 * 
	 * @return an URI
	 */
	public Value<URI> readWithRestrictions() {
		return applyOperator(Operator.READ, null, URI, WITH_RESTRICTIONS, URI.class, null);
	}


	/**
	 * Write the The property that determines the collection of facet-value pairs that define a datatype restriction.
	 * 
	 * @param value
	 *            an URI
	 */
	public PieceOfKnowledge writeWithRestrictions(URI value) {
		return applyOperator(Operator.WRITE, PREFIX, URI, WITH_RESTRICTIONS, URI.class, value).getIsAnnotatedOn();
	}




}
