/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

package org.geonames.www.ontology;

import java.net.URI;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;
import org.ow2.weblab.rdf.XMLParser;

/**
 * Simplified Geonames Ontology
 * 
 * This version is provided as en example to generate Geonames annotator
 */
public class WGeonamesAnnotator extends BaseAnnotator {

	protected static final String PREFIX = "wgeonames";
	protected static final URI URI = XMLParser.buildURI("http://www.geonames.org/ontology#");

	public WGeonamesAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge) {
		super(subject, pieceOfKnowledge);
	}

	public WGeonamesAnnotator(Resource resource) {
		super(resource);
	}

	/**
	 * Read the Gives a name for the feature.
	 * 
	 * @return a String
	 */
	public Value<String> readName() {
		return applyOperator(Operator.READ, null, URI, NAME, String.class, null);
	}


	/**
	 * Write the Gives a name for the feature.
	 * 
	 * @param value
	 *            a String
	 */
	public void writeName(String value) {
		applyOperator(Operator.WRITE, PREFIX, URI, NAME, String.class, value);
	}


	/**
	 * Read the the population living in the feature.
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readPopulation() {
		return applyOperator(Operator.READ, null, URI, POPULATION, Integer.class, null);
	}


	/**
	 * Write the the population living in the feature.
	 * 
	 * @param value
	 *            an Integer
	 */
	public void writePopulation(Integer value) {
		applyOperator(Operator.WRITE, PREFIX, URI, POPULATION, Integer.class, value);
	}


	/**
	 * Read the Latitude of the Feature
	 * 
	 * @return a Double
	 */
	public Value<Double> readWgs84_pos_lat() {
		return applyOperator(Operator.READ, null, URI, WGS84_POSLAT, Double.class, null);
	}


	/**
	 * Write the Latitude of the Feature
	 * 
	 * @param value
	 *            a Double
	 */
	public void writeWgs84_pos_lat(Double value) {
		applyOperator(Operator.WRITE, PREFIX, URI, WGS84_POSLAT, Double.class, value);
	}


	/**
	 * Read the Longitude of the Feature
	 * 
	 * @return a Double
	 */
	public Value<Double> readWgs84_pos_long() {
		return applyOperator(Operator.READ, null, URI, WGS84_POSLONG, Double.class, null);
	}


	/**
	 * Write the Longitude of the Feature
	 * 
	 * @param value
	 *            a Double
	 */
	public void writeWgs84_pos_long(Double value) {
		applyOperator(Operator.WRITE, PREFIX, URI, WGS84_POSLONG, Double.class, value);
	}


	protected static final String NAME = "name";
	protected static final String POPULATION = "population";
	protected static final String WGS84_POSLAT = "http://www.w3.org/2003/01/geo/wgs84_pos#lat";
	protected static final String WGS84_POSLONG = "http://www.w3.org/2003/01/geo/wgs84_pos#long";

}
