/**
* WEBLAB: Service oriented integration platform for media mining and intelligence applications
*  
* Copyright (C) 2004 - 2011 Cassidian, an EADS company
* 
* This library is free software; you can redistribute it and/or modify it under the terms of
* the GNU Lesser General Public License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
* 
* This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
* See the GNU Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public License along with this
* library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
* Floor, Boston, MA 02110-1301 USA
*/
package org.ow2.weblab.core.annotator;

import java.net.URI;

import junit.framework.TestCase;

import org.ow2.weblab.core.extended.factory.ResourceFactory;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.processing.WProcessingAnnotator;

public class RemoveStatement extends TestCase {

	
	public void testRemoveProperty(){
		PieceOfKnowledge pok = ResourceFactory.createResource("pok", "res", PieceOfKnowledge.class);
		URI pokURI = URI.create(pok.getUri());
		
		WProcessingAnnotator wpa = new WProcessingAnnotator(pokURI, pok);
		
		
		// try to delete a statement that does not exist
		wpa.setAppendMode(false);
		PieceOfKnowledge p = wpa.writeExposedAs(null);
		
		// it should fail 
		assertNull(p);
		
		// write a property
		p = wpa.writeExposedAs("test");
		
		assertNotNull(p);
		assertEquals("test", wpa.readExposedAs().firstTypedValue());
		
		// force append mode
		wpa.setAppendMode(true);
		
		// append mode is not compatible with statement deletion
		// This will throw a catched exception
		// the result of a deletion/write should be checked by the returned value
		// if the returned POK is null, then the operation failed,
		// else all went well.
		p = wpa.writeExposedAs(null);
		
		// Thus the return POK should be null
		assertNull(p);
		
		// force override mode
		wpa.setAppendMode(false);
		
		// try to remove all properties on this POK  
		p = wpa.writeExposedAs(null);
		
		assertNotNull(p);
		assertNull(wpa.readExposedAs());
		
	}
}
