/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

package org.ow2.weblab.rdf;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.StringWriter;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import com.hp.hpl.jena.ontology.OntModel;
import com.hp.hpl.jena.ontology.OntProperty;
import com.hp.hpl.jena.ontology.OntResource;
import com.hp.hpl.jena.ontology.Ontology;
import com.hp.hpl.jena.rdf.model.ModelFactory;
import com.hp.hpl.jena.util.iterator.ExtendedIterator;

public class OWL2Annotator {

	private static final String WRITE = "return applyOperator(Operator.WRITE, !!PREFIX!!,!!URI!!, !!FIELD!!, !!CLASS!!.class, value).getIsAnnotatedOn();";
	private static final String READ = "return applyOperator(Operator.READ, null,!!URI!!, !!FIELD!!, !!CLASS!!.class, null);";

	private static final String FIRST_VALUE_COMMENT = "";
	
	private static Set<OntProperty> properties = new HashSet<OntProperty>();
	
	public static void main(String[] args){

		String pbase = null;
//		String ontology = "ontologies/model.owl";
//		String ontology = "ontologies/processing.owl";
		String ontology = "ontologies/retrieval.owl";
		
//		String ontology = "src/test/resources/dcterms.rdf"; 
//		String pbase = "http://purl.org/dc/terms/";
		
		if (args != null && args.length > 0){
			ontology = args[0];
		}
		
		parseOntology(ontology, pbase);
	}
	
	private static void parseOntology(String ontology, String pbase){
		properties.clear();
		
		InputStream is = ClassLoader.getSystemClassLoader().getResourceAsStream(ontology);
		
		OntModel ontmodel = ModelFactory.createOntologyModel();
		ontmodel.read(is, pbase);

		
		Map<String, String> namesspaces = ontmodel.getNsPrefixMap(); 
			
		String base = namesspaces.get("");
		
		base = base == null?pbase:base;
		
		if (base != null){
			loadOWL(base, ontmodel);
		}else{
			System.err.println("If you want to parse a RDF file, please provide the base uri please");
		}

	}
	

	private static void loadOWL(String base, OntModel ontmodel) {
		ExtendedIterator<OntProperty> it = ontmodel.listAllOntProperties();
		while(it.hasNext()){
			OntProperty op = it.next();
			if (!op.isAnon()){
				if (op.getDomain() != null && op.getDomain().isClass() && op.getNameSpace().equals(base)){
					properties.add(op);
//					System.out.println(op.getDomain() +" " +op.toString()+" "+op.getRange());
				}else if (op.getDomain() == null && op.getNameSpace().equals(base)){
					System.out.println(op.getDomain() +" " +op.toString()+" "+op.getRange());
					properties.add(op);
					// other property with domain and range not defined
				}else{
//					System.out.println(op.getDomain() +" " +op.toString()+" "+op.getRange());
					// other property RDF/RDFS/OWL not specific to this ontology
				}
			}
		}
		
		
		ExtendedIterator<Ontology> io = ontmodel.listOntologies();
		String comment = ""; 
		if(io.hasNext()){
			Ontology o = io.next();
			comment = o.getComment(null);
		}
		
		try {
			writeAnnotator(base, comment);
		} catch (IOException e) {
			e.printStackTrace();
		}
		
	}

	private static void writeAnnotator(String base, String comment) throws IOException {
		
		
		String prefix = "w"+prefixFrom(base);
		String className = prefix.substring(0,2).toUpperCase() + prefix.substring(2) + "Annotator";
		String packageName = pakageFrom(base);
		
		FileWriter fw = new FileWriter(new File(className + ".java"));
		fw.write("package " + packageName + ";\n\n");
		fw.write("import java.net.URI;\n");
		fw.write("import java.util.Date;\n");
		fw.write("import org.ow2.weblab.rdf.Value;\n");
		fw.write("import org.ow2.weblab.core.model.*;\n");
		fw.write("import org.ow2.weblab.core.annotator.*;\n\n");

		fw.write(generateJavaComment(comment,null,null).replaceAll("\t", " ") + "public class " + className + " extends BaseAnnotator {\n\n");

		fw.write("\tprotected static final String APREFIX = \"" + prefix + "\";\n");
		fw.write("\tprotected static final URI AURI = URI.create(\"" + base + "\");\n\n");
		fw.write("\tpublic " + className + "(URI subject, PieceOfKnowledge pieceOfKnowledge){\n");
		fw.write("\t\tsuper(subject,pieceOfKnowledge);\n");
		fw.write("\t}\n\n");


		fw.write("\tpublic " + className + "(Resource resource){\n");
		fw.write("\t\tsuper(resource);\n");
		fw.write("\t}\n\n");

		writeProperties(prefix, base, fw);

		fw.write("\n}\n\n");

		fw.close();
	}
	
	private static void writeProperties(String prefix, String base, FileWriter fw) throws IOException {
		
		StringWriter sw = new StringWriter();
		
		StringWriter pw = new StringWriter();
		
		for(OntProperty property:properties){
			
			OntResource or = property.getRange();
//			System.out.println(property.getDomain() +" " +property.toString()+" "+property.getRange());
			String range;
			if (or == null){
				range = "string";
			}else if(or.isAnon() || or.getNameSpace().endsWith(base)){
				range = "anyURI";
			}else{
				range =or.getLocalName();
			}
			
			
			String type = retrieveType(range);
			String value = property.getLocalName();
			String field = generateStaticField(cleanProperty(value));
			String cleanedValue = value.replaceAll("&", "").replace(';', '_');
			String comment = property.getComment(null);
			
			String getter = generateGetter("AURI", cleanedValue, field, type, comment);
			String setter = generateSetter("APREFIX", "AURI", cleanedValue, field, type, comment);

			pw.append(getter + "\n");
			pw.append(setter + "\n");
			
			sw.append("\tprotected static final String " + field + " = \"" + value + "\";\n");
		}

		sw.append("\n");
		
		fw.write(sw.toString());
		
		fw.write(pw.toString());
	}
	
	private static String cleanProperty(String property) {
		property = property.replaceAll("(\\.|-)", "_");
		if (property.indexOf("\"") != -1) {
			int e = property.indexOf("\"");
			return property.substring(0, e);
		}
		return property;
	}
	
	private static String generateStaticField(String value) {
		StringBuffer res = new StringBuffer();
		for (int i = 0; i < value.length(); i++) {
			char c = value.charAt(i);
			if (!(c + "").toLowerCase().equals("" + c)) {
				res.append("_");
			}
			res.append(c);
		}
		return res.toString().replaceAll("(&|;)", "").toUpperCase();
	}

	private static String retrieveType(String r) {
		if (r.matches("int")) {
			return "Integer";
		} else if (r.matches("long|double|boolean|string|date")) {
			return ((char) (r.charAt(0) + ('A' - 'a'))) + r.substring(1);
		} else if (r.matches("(.*Thing|.*Literal)")) {
			return "String";
		} else {
			return "URI";
		}
	}
	
	private static String generateGetter(String baseURI, String value, String field, String type, String comment) {

		if (value.startsWith("has")) {
			value = "read" + value.substring(3, 4).toUpperCase() + value.substring(4);
		} else if (value.startsWith("is") && (value.charAt(3)+"").equals(value.charAt(3)+"".toUpperCase())) {
			value = "read" + value.substring(2, 3).toUpperCase() + value.substring(3);
		} else {
			value = "read" + value.substring(0, 1).toUpperCase() + value.substring(1);
		}

		String res = "\tpublic Value<" + type + "> " + value + "(){\n" + "\t\t"
				+ READ.replaceFirst("!!URI!!", baseURI).replaceFirst("!!FIELD!!", field).replaceFirst("!!CLASS!!", type) + "\n" + "\t}\n\n";
		return generateJavaComment("Read the " + comment + " \n" + FIRST_VALUE_COMMENT, null, type) + res;
	}

	private static String generateSetter(String prefixURI, String baseURI, String value, String field, String type, String comment) {
		if (value.startsWith("has")) {
			value = "write" + value.substring(3, 4).toUpperCase() + value.substring(4);
		} else if (value.startsWith("is")) {
			value = "write" + value.substring(2, 3).toUpperCase() + value.substring(3);
		} else {
			value = "write" + value.substring(0, 1).toUpperCase() + value.substring(1);
		}

		String res = "\tpublic PieceOfKnowledge " + value + "(" + type + " value){\n" + "\t\t"
				+ WRITE.replaceFirst("!!URI!!", baseURI).replaceFirst("!!PREFIX!!", prefixURI).replaceFirst("!!FIELD!!", field).replaceFirst("!!CLASS!!", type)
				+ "\n" + "\t}\n\n";
		return generateJavaComment("Write the " + comment, type, null) + res;
	}

	private static String generateJavaComment(String comment, String param, String ret) {
		String res = "\t/**\n";
		res += "\t * " + comment.replaceAll("( |\\t)+", " ").replaceAll("\\n", "\n\t * ");
		if (param != null) {
			String des = desFrom(param);
			res += "\n\t * @param value " + des + param;
		}
		if (ret != null) {
			String des = desFrom(ret);
			res += "\n\t * @return " + des + ret;
		}
		return res + "\n\t */\n";
	}
	
	private static String desFrom(String param) {
		switch (param.toLowerCase().charAt(0)) {
			case 'a':
			case 'e':
			case 'i':
			case 'o':
			case 'u':
			case 'y':
				return "an ";
			default:
				break;
		}
		return "a ";
	}

	private static String pakageFrom(String baseURI) {
		String[] split = baseURI.split("/");
		StringBuffer res = new StringBuffer();
		for (String s : split) {
			if (s.matches(".*\\..*")) {
				String[] parts = s.split("\\.");
				String sr = "";
				for (String p : parts) {
					sr = p + "." + sr;
				}
				res.append("." + sr);
			} else {
				res.append("." + s);
			}
		}
		return res.substring(8, res.length() - 1).replaceAll("\\.+", ".").replaceAll("(-|\\(|\\))", "_");
	}
	
	private static String prefixFrom(String baseURI) {
		int l = baseURI.lastIndexOf('/', baseURI.length() - 2);
		String prefix = baseURI.substring(l + 1, baseURI.length() - 1);
		if (prefix.equalsIgnoreCase("ontology") || prefix.matches("\\d+(\\.\\d+)*")) {
			int s = baseURI.lastIndexOf('/', l - 1);
			prefix = baseURI.substring(s + 1, l);
			prefix = prefix.replaceAll("(www\\.|\\.(org|net|com|fr))", "");
		}
		return prefix;
	}
}
