/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

package org.ow2.weblab.rdf;

import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.Date;

import junit.framework.TestCase;

import org.ow2.weblab.core.annotator.AbstractAnnotator.Operator;
import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.annotator.Element;
import org.ow2.weblab.core.extended.factory.ResourceFactory;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;


public class RDFTest extends TestCase {

	static final Element element = Element.getDefaultElement();

	public void testConstructors() {
		Constructor<?> c = RDFWriter.class.getDeclaredConstructors()[0];
		c.setAccessible(true);
		try {
			c.newInstance(new Object[] {});
			fail();
		} catch (Exception e) {
		}
		c = RDFReader.class.getDeclaredConstructors()[0];
		c.setAccessible(true);
		try {
			c.newInstance(new Object[] {});
			fail();
		} catch (Exception e) {
		}
	}
	
	public void setXMLParser(String parserName){
		try {
			Field field = RDFWriter.class.getDeclaredField("XML_PARSER_CLASS");
			field.setAccessible(true);
			
			Field modifiersField = Field.class.getDeclaredField("modifiers");
		    modifiersField.setAccessible(true);
		    modifiersField.setInt(field, field.getModifiers() & ~Modifier.FINAL);

		    field.set(null, parserName);
			
		} catch (SecurityException e) {
			e.printStackTrace();
		} catch (NoSuchFieldException e) {
			e.printStackTrace();
		} catch (IllegalArgumentException e) {
			e.printStackTrace();
		} catch (IllegalAccessException e) {
			e.printStackTrace();
		}
		
	}

	public void testWrite() throws URISyntaxException {

		final Annotation annotation = ResourceFactory.createResource("idfact", "myAnnot", Annotation.class);
		final String RDF_PREFIX = "rdf";
		final String RDF_URI = "http://www.w3.org/1999/02/22-rdf-syntax-ns#";
		final String DUBLIN_CORE_PREFIX = "dc";
		final String DUBLIN_CORE_URI = "http://purl.org/dc/elements/1.1/";

		try {
			RDFWriter.writeStatement(annotation, new URI("http://myobject#1"), RDF_PREFIX, new URI(RDF_URI), "type", new URI("weblab://myWeblab/uri"), null,
					true, element);
			RDFWriter.writeStatement(annotation, new URI("http://myobject#1"), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "title", "test", "fr", true,
					element);
			RDFWriter.writeStatement(annotation, new URI("http://myobject#1"), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "title", "test", null, false,
					element);
			RDFWriter.writeStatement(annotation, new URI("http://myobject#1"), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "title", "test_en", "en", true,
					element);
			RDFWriter.writeStatement(annotation, new URI(annotation.getUri()), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "creator", "me", null, true,
					element);
			RDFWriter.writeStatement(annotation, new URI(annotation.getUri()), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "creator", "me2", null, true,
					element);
			RDFWriter.writeStatement(annotation, new URI(annotation.getUri()), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "author", new URI(
					"weblab://myWeblab/uri"), "de", true, element);
		} catch (final Exception e) {
			e.printStackTrace();
			fail();
		}

		try {
			// not found
			RDFWriter.outputFactory = null;
			setXMLParser("org.ow2.weblab.rdf.DummyXMLParser");
			RDFWriter.writeStatement(annotation, new URI(annotation.getUri()), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "creator", "me2", null, true,
					element);
		} catch (Exception e) {
			e.printStackTrace();
			fail();
		}

		try {
			// instantiation
			RDFWriter.outputFactory = null;
			setXMLParser("org.ow2.weblab.rdf.UnInstantiableXMLParser");
			RDFWriter.writeStatement(annotation, new URI(annotation.getUri()), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "creator", "me2", null, true,
					element);
		} catch (Exception e) {
			e.printStackTrace();
			fail();
		}

		try {
			// Illegal
			RDFWriter.outputFactory = null;
			setXMLParser("org.ow2.weblab.rdf.IllegalXMLParser");
			RDFWriter.writeStatement(annotation, new URI(annotation.getUri()), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "creator", "me2", null, true,
					element);
		} catch (Exception e) {
			e.printStackTrace();
			fail();
		}

//		TODO: rewrite
//		try {
//			// do nothing
//			RDFWriter.outputFactory = null;
//			setXMLParser("org.ow2.weblab.rdf.LazyXMLParser");
//			RDFWriter.writeStatement(annotation, new URI("an:other"), DUBLIN_CORE_PREFIX, new URI(DUBLIN_CORE_URI), "creator", "me2", null, true, element);
//			fail();
//		} catch (Exception e) {
//			RDFWriter.outputFactory = null;
//			setXMLParser("com.sun.xml.internal.stream.XMLOutputFactoryImpl");
//		}

		BaseAnnotator bas = new BaseAnnotator(annotation);
		bas.applyOperator(Operator.WRITE, "no:test", URI.create("no:test"), null, String.class, "");

		assertNull(RDFReader.readValueFromStatement(new PieceOfKnowledge(), URI.create("no:test"), null, null, null, null, element));



		DNode ni = new DNode();
		assertNull(RDFReader.getLanguage(ni));
		assertNull(RDFReader.getLanguage(new DNode() {

			public NamedNodeMap getAttributes() {
				return new DNamedNodeMap() {

					public Node getNamedItem(String name) {
						return null;
					}
				};
			}
		}));
		assertNull(RDFReader.findElementAboutIn(null, "test", element));

		Node n = new DNode() {

			public NodeList getChildNodes() {
				return new NodeList() {

					@Override
					public Node item(int index) {
						return new DNode() {

							public NodeList getChildNodes() {
								return new NodeList() {

									@Override
									public int getLength() {
										return 0;
									}

									@Override
									public Node item(int index) {
										return null;
									}

								};
							}
						};
					}

					@Override
					public int getLength() {
						return 1;
					}
				};
			}
		};
		RDFReader.print(n, "");
		assertNull(RDFReader.findRDF(n));
		assertFalse(RDFReader.isElementAbout(null, "dummy", element));


		Node nd = new DNode() {

			public String getLocalName() {
				return "description";
			}

			public String getNamespaceURI() {
				return CommonNamespaces.RDF_URI;
			}

			public NamedNodeMap getAttributes() {
				return new DNamedNodeMap() {

					public Node getNamedItemNS(String uri, String name) {
						return new DNode() {

							public String getTextContent() {
								return "some";
							}
						};
					}
				};
			}
		};
		assertEquals(nd, RDFReader.findElementAbout(nd, "some", element));

		Node nfd = new DNode() {

			public String getLocalName() {
				return "description";
			}

			public String getNamespaceURI() {
				return CommonNamespaces.RDF_URI;
			}

			public NamedNodeMap getAttributes() {
				return new DNamedNodeMap() {

				};
			}
		};
		assertFalse(RDFReader.isElementAbout(nfd, "some", element));

		Node nulld = new DNode() {

			public String getLocalName() {
				return "description";
			}

			public String getNamespaceURI() {
				return CommonNamespaces.RDF_URI;
			}

			public NamedNodeMap getAttributes() {
				return new DNamedNodeMap() {

					public Node getNamedItemNS(String uri, String name) {
						return new DNode();
					}
				};
			}
		};
		assertFalse(RDFReader.isElementAbout(nulld, "some", element));

		Value<String> result = RDFReader.readValueFromStatement(annotation, new URI(annotation.getUri()), new URI(DUBLIN_CORE_URI), "creator", null,
				String.class, element);
		assertEquals("me", result.toString());
		result = RDFReader.readValueFromStatement(annotation, new URI(annotation.getUri()), new URI(DUBLIN_CORE_URI), "title", null, String.class, element);
		assertNull(result);
		result = RDFReader.readValueFromStatement(annotation, new URI("http://myobject#1"), new URI(DUBLIN_CORE_URI), "title", "en", String.class, element);
		assertEquals("test_en", result.toString());

		assertTrue(result.hasValue());
		assertEquals("test_en", result.toString());
		assertEquals("test_en", result.firstTypedValue());
		assertEquals(1, result.size());
		assertTrue(result.iterator().hasNext());
		// new WebLabMarshaler().marshalResource(annotation, System.out);

		new XMLParser();
		assertEquals("", XMLParser.xmlParse("", Date.class));
		assertNull(XMLParser.xmlParse(null, String.class));
		assertEquals(12.4, XMLParser.xmlParse("12.4", double.class));
		assertEquals(12213543543l, XMLParser.xmlParse("12213543543", long.class).longValue());
		assertEquals(12, XMLParser.xmlParse("12", int.class).intValue());
		assertFalse(XMLParser.xmlParse("false", boolean.class));
		assertEquals("not an uri", XMLParser.xmlParse("not an uri", URI.class));
		assertNull(XMLParser.buildURI("not an uri"));
		Value<?> v = new Value();
		assertFalse(v.hasValue());
		assertNull(v.firstTypedValue("fr"));
		assertNull(v.firstTypedValue(null));
		assertNull(v.toString());
		Value<String> v2 = new Value<String>();
		v2.addItem("item", "fr");
		assertEquals("item", v2.firstTypedValue("fr"));
		assertNull(v2.firstTypedValue("en"));
		assertEquals("item", v2.firstTypedValue());


	}
}
