/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.extended.factory;

import java.io.StringWriter;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;

import junit.framework.Assert;

import org.junit.Ignore;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.exception.WebLabResourceCreationException;
import org.ow2.weblab.core.extended.exception.WebLabUncheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.uri.WebLabRI;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.Image;
import org.ow2.weblab.core.model.LinearSegment;
import org.ow2.weblab.core.model.LowLevelDescriptor;
import org.ow2.weblab.core.model.MediaUnit;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.core.model.ResultSet;
import org.ow2.weblab.core.model.Segment;
import org.ow2.weblab.core.model.SpatialSegment;
import org.ow2.weblab.core.model.SpatioTemporalSegment;
import org.ow2.weblab.core.model.TemporalSegment;
import org.ow2.weblab.core.model.Text;
import org.ow2.weblab.core.model.TrackSegment;

/**
 *
 */
public class TestFactories {


	/**
	 * 
	 */
	@Test
	@Deprecated
	public void testFactories() throws WebLabCheckedException {
		// DocumentFactory tests
		Document doc = null;

		// this tests must failed because of '#'
		try {
			doc = ResourceFactory.createResource("test_1", "666-666#", Document.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException wrce) {
			Assert.assertNotNull(wrce);
		}

		try {
			doc = ResourceFactory.createResource("test_1", "666-666#99", Document.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException wrce) {
			Assert.assertNotNull(wrce);
		}

		try {
			doc = ResourceFactory.createResource("test_1#", "666-666", Document.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException wrce) {
			Assert.assertNotNull(wrce);
		}

		// this one is right
		doc = ResourceFactory.createResource("test_1", "666-666", Document.class);

		Assert.assertEquals("weblab://test_1/666-666", doc.getUri());
		Assert.assertNotSame("weblab://test_2/666", doc.getUri());

		// MediaUnitFactory tests
		final Text text1 = MediaUnitFactory.createAndLinkMediaUnit(doc, Text.class);

		Assert.assertEquals("weblab://test_1/666-666#0", text1.getUri());

		final Document comp = MediaUnitFactory.createAndLinkMediaUnit(doc, Document.class);

		Assert.assertEquals("weblab://test_1/666-666#1", comp.getUri());

		final Text text2 = MediaUnitFactory.createAndLinkMediaUnit(comp, Text.class);

		Assert.assertEquals("weblab://test_1/666-666#1-2", text2.getUri());

		final Document comp2 = MediaUnitFactory.createAndLinkMediaUnit(comp, Document.class);
		Assert.assertEquals("weblab://test_1/666-666#1-3", comp2.getUri());

		text1.setContent("Text du premier niveau");
		text2.setContent("Text du deuxième niveau");

		// AnnotationFactory tests
		final Annotation annot1 = AnnotationFactory.createAndLinkAnnotation(doc);
		Assert.assertEquals("weblab://test_1/666-666#a4", annot1.getUri());
		final Annotation annot2 = AnnotationFactory.createAndLinkAnnotation(text1);
		Assert.assertEquals("weblab://test_1/666-666#0-a5", annot2.getUri());
		final Annotation annot3 = AnnotationFactory.createAndLinkAnnotation(text1);
		Assert.assertEquals("weblab://test_1/666-666#0-a6", annot3.getUri());
		final Annotation annot4 = AnnotationFactory.createAndLinkAnnotation(annot1);
		Assert.assertEquals("weblab://test_1/666-666#a4-a7", annot4.getUri());
		final Annotation annot5 = AnnotationFactory.createAndLinkAnnotation(annot3);
		Assert.assertEquals("weblab://test_1/666-666#0-a6-a8", annot5.getUri());

		try {
			final Resource res = ResourceFactory.createResource("idRef", "idRess", Resource.class);
			res.setUri("khfdjkf--[");
			AnnotationFactory.createAndLinkAnnotation(res);
			Assert.fail("'[' not allowed in URI of parent.");
		} catch (final WebLabResourceCreationException wlrce) {
			Assert.assertNotNull(wlrce);
		}

		final LowLevelDescriptor lld = LowLevelDescriptorFactory.createAndLinkLowLevelDescriptor(text1);
		LowLevelDescriptorFactory.createAndLinkLowLevelDescriptor(text1);
		Assert.assertEquals(null, lld.getData());

		/*
		 * Simple segment types first
		 */
		SegmentFactory.createAndLinkSegment(text1, LinearSegment.class);
		SegmentFactory.createAndLinkSegment(text1, TemporalSegment.class);
		SegmentFactory.createAndLinkSegment(text1, SpatialSegment.class);
		SegmentFactory.createAndLinkSegment(text1, SpatioTemporalSegment.class);
		final TrackSegment track1 = SegmentFactory.createAndLinkSegment(text1, TrackSegment.class);
		SegmentFactory.createAndLinkSegment(track1, LinearSegment.class);
		SegmentFactory.createAndLinkSegment(track1, TemporalSegment.class);
		SegmentFactory.createAndLinkSegment(track1, SpatialSegment.class);
		SegmentFactory.createAndLinkSegment(track1, SpatioTemporalSegment.class);

		/*
		 * Bad input for linear
		 */
		try {
			SegmentFactory.createAndLinkLinearSegment(text1, 5, 2);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkLinearSegment((Text) null, 2, 5);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkLinearSegment(track1, 5, 2);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkLinearSegment((TrackSegment) null, 2, 5);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}

		/*
		 * Bad input for temporal
		 */
		try {
			SegmentFactory.createAndLinkTemporalSegment(text1, 5, 2);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkTemporalSegment((Text) null, 2, 5);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkTemporalSegment(track1, 5, 2);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkTemporalSegment((TrackSegment) null, 2, 5);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}

		/*
		 * Bad input for spatial
		 */
		try {
			SegmentFactory.createAndLinkSpatialSegment((Text) null, new int[4]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatialSegment(text1, null);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatialSegment(text1, new int[2]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatialSegment(text1, new int[11]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatialSegment((TrackSegment) null, new int[4]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatialSegment(track1, null);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatialSegment(track1, new int[2]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatialSegment(track1, new int[11]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}

		/*
		 * Bad input for spatiotemporal
		 */
		try {
			SegmentFactory.createAndLinkSpatioTemporalSegment((Text) null, 12, new int[4]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatioTemporalSegment(text1, 12, null);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatioTemporalSegment(text1, 12, new int[2]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatioTemporalSegment(text1, 12, new int[79]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatioTemporalSegment((TrackSegment) null, 12, new int[4]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatioTemporalSegment(track1, 12, null);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatioTemporalSegment(track1, 12, new int[2]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}
		try {
			SegmentFactory.createAndLinkSpatioTemporalSegment(track1, 12, new int[79]);
			Assert.fail();
		} catch (final WebLabUncheckedException wlue) {
			Assert.assertNotNull(wlue);
		}

		/*
		 * Test various linear segment creation
		 */
		final Segment sl1 = SegmentFactory.createAndLinkLinearSegment(text1, 2, 5);
		final Segment sl1bis = SegmentFactory.createAndLinkLinearSegment(text1, 2, 5);
		final Segment sl1ter = SegmentFactory.createAndLinkLinearSegment(text1, 2, 5, true);

		final Segment sl2 = SegmentFactory.createAndLinkLinearSegment(text1, 2, 6);
		final Segment sl3 = SegmentFactory.createAndLinkLinearSegment(text1, 3, 5);

		Assert.assertEquals(sl1, sl1bis);
		Assert.assertNotSame(sl1, sl1ter);
		Assert.assertNotSame(sl1bis, sl1ter);
		Assert.assertNotSame(sl1, sl3);
		Assert.assertNotSame(sl1bis, sl2);
		Assert.assertNotSame(sl2, sl3);

		SegmentFactory.createAndLinkLinearSegment(track1, 3, 5);

		/*
		 * Test various temporal segment creation
		 */
		final Segment st1 = SegmentFactory.createAndLinkTemporalSegment(text1, 2, 5);
		final Segment st1bis = SegmentFactory.createAndLinkTemporalSegment(text1, 2, 5);
		final Segment st1ter = SegmentFactory.createAndLinkTemporalSegment(text1, 2, 5, true);

		final Segment st2 = SegmentFactory.createAndLinkTemporalSegment(text1, 2, 6);
		final Segment st3 = SegmentFactory.createAndLinkTemporalSegment(text1, 3, 5);

		Assert.assertEquals(st1, st1bis);
		Assert.assertNotSame(st1, st1ter);
		Assert.assertNotSame(st1bis, st1ter);
		Assert.assertNotSame(st1, st3);
		Assert.assertNotSame(st1bis, st2);
		Assert.assertNotSame(st2, st3);

		SegmentFactory.createAndLinkTemporalSegment(track1, 2, 5);

		/*
		 * Test good spatial segment creation
		 */
		SegmentFactory.createAndLinkSpatialSegment(text1, new int[] { 5, 4, 5, 3, 6, 5 });
		SegmentFactory.createAndLinkSpatialSegment(track1, new int[] { 5, 4, 5, 3, 6, 5 });


		/*
		 * Test good spatiotemporal segment creation
		 */
		SegmentFactory.createAndLinkSpatioTemporalSegment(text1, 54, new int[] { 5, 4, 5, 3, 6, 5 });
		SegmentFactory.createAndLinkSpatioTemporalSegment(track1, 54, new int[] { 5, 4, 5, 3, 6, 5 });


		AnnotationFactory.createAndLinkAnnotation(text1);

		new WebLabMarshaller().marshalResource(text1, new StringWriter());

		System.out.println("testFactories: OK");
	}


	/**
	 * 
	 */
	@Test
	@Ignore
	@Deprecated
	public void testCreateAndLinkMediaUnit() {
		final Document d = ResourceFactory.createResource("test", "doc", Document.class);
		final Set<String> uris = new HashSet<String>();
		final int size = 30;
		for (int k = 0; k < size; k++) {
			final Text t = MediaUnitFactory.createAndLinkMediaUnit(d, Text.class);
			uris.add(t.getUri());
			final WebLabRI uri = new WebLabRI(t.getUri());
			Assert.assertEquals("" + k, uri.getFragment());
		}
		Assert.assertEquals(size, uris.size());
	}


	/**
	 * 
	 */
	@Test
	public void testUnbearableNumberofElementCreation() {
		final Document document = ResourceFactory.createResource("test", "overDocument", Document.class);
		int sum = 1;

		int size = 5;
		sum += size;
		// Creates Texts
		final List<Text> res = new LinkedList<Text>();
		for (int k = 0; k < size; k++) {
			res.add(MediaUnitFactory.createAndLinkMediaUnit(document, Text.class));
		}

		final List<Segment> resS = new LinkedList<Segment>();
		// Creates Segments
		size = 15000;
		sum += size;
		for (int k = 0; k < size; k++) {
			final Text t = res.get((int) Math.floor(Math.random() * 5));
			final int s = k;// (int)Math.floor(Math.random()*100000);
			final int end = k + 1;// s+1+(int)Math.floor(Math.random()*100000);
			resS.add(SegmentFactory.createAndLinkLinearSegment(t, s, end));
		}

		// Creates Annotations
		size = 50000;
		sum += size;
		for (int k = 0; k < size; k++) {
			final Text t = res.get((int) Math.floor(Math.random() * 5));
			AnnotationFactory.createAndLinkAnnotation(t);
		}

		Assert.assertEquals(sum, AbstractFactory.listUri(document, true).size());

	}


	/**
	 * 
	 */
	@Test
	public void testBuffer() {
		final Document doct = new Document();
		doct.setUri("doct");
		final LowLevelDescriptor lld = new LowLevelDescriptor();
		lld.setUri("lld");
		doct.getDescriptor().add(lld);
		final Annotation a = new Annotation();
		a.setUri("ann");
		doct.getAnnotation().add(a);
		final Segment s = new LinearSegment();
		s.setUri("seg");
		doct.getSegment().add(s);
		final Text t = new Text();
		t.setUri("t");
		t.getSegment().add(s);
		doct.getMediaUnit().add(t);
		Assert.assertEquals(5, AbstractFactory.listUri(doct, true).size());

		final ComposedResource cr = new ComposedResource();
		cr.setUri("cr");
		cr.getResource().add(doct);
		Assert.assertEquals(6, AbstractFactory.listUri(cr, true).size());

		AbstractFactory.removeChild(doct, cr, cr);
		Assert.assertEquals(1, AbstractFactory.listUri(cr, true).size());
		AbstractFactory.removeChild(doct, null, cr);
		Assert.assertEquals(1, AbstractFactory.listUri(cr, true).size());

		/*
		 * deprecated test
		 */
		// AbstractFactory.addChild(doct, null, cr);
		// assertEquals(1, AbstractFactory.listUri(cr, true).size());

		AbstractFactory.addChild(doct, cr, cr);
		Assert.assertEquals(6, AbstractFactory.listUri(cr, true).size());

		Assert.assertEquals(cr, AbstractFactory.findParent(doct, cr));
		Assert.assertNull(AbstractFactory.findParent(doct, null));
		Assert.assertNull(AbstractFactory.findParent(doct, new Document()));
		Assert.assertEquals(doct, AbstractFactory.findParent(t, cr));

		final Document doc = new Document();
		doc.setUri("http://my test");
		for (int i = 0; i < 1002; i++) {
			doc.setUri("http://my test" + i);
			AbstractFactory.listUri(doc, true);
		}
		Assert.assertTrue(AbstractFactory.innerMap.size() <= 1001);
	}


	@Test
	@Deprecated
	public void testDeprecatedCreateAndLinkMediaUnit() {

		final Document doc = new Document();
		try {
			MediaUnitFactory.createAndLinkMediaUnit((Resource) doc, MediaUnit.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}
		try {
			doc.setUri("not an uri !");
			MediaUnitFactory.createAndLinkMediaUnit((Resource) doc, Image.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

		try {
			MediaUnitFactory.createAndLinkMediaUnit((Resource) doc, DummyResource2.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

		try {
			doc.setUri("weblab://this.one.is.valid/1");
			final Text text = MediaUnitFactory.createAndLinkMediaUnit((Resource) doc, Text.class);
			/*
			 * MUST AVOID THE TREE CREATION
			 */
			MediaUnitFactory.createAndLinkMediaUnit(text, Text.class);
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}


	}


	/**
	 * @throws Exception
	 *             If instanciations fails
	 */
	@Test
	public void testWithIntro() throws Exception {
		try {
			for (final Constructor<?> c : AnnotationFactory.class.getDeclaredConstructors()) {
				c.setAccessible(true);
				c.newInstance();
			}
			Assert.fail();
		} catch (final InvocationTargetException ite) {
			if (!(ite.getCause() instanceof UnsupportedOperationException)) {
				Assert.fail();
			}
		}
		try {
			for (final Constructor<?> c : LowLevelDescriptorFactory.class.getDeclaredConstructors()) {
				c.setAccessible(true);
				c.newInstance();
			}
			Assert.fail();
		} catch (final InvocationTargetException ite) {
			if (!(ite.getCause() instanceof UnsupportedOperationException)) {
				Assert.fail();
			}
		}
		try {
			for (final Constructor<?> c : MediaUnitFactory.class.getDeclaredConstructors()) {
				c.setAccessible(true);
				c.newInstance();
			}
			Assert.fail();
		} catch (final InvocationTargetException ite) {
			if (!(ite.getCause() instanceof UnsupportedOperationException)) {
				Assert.fail();
			}
		}
		try {
			for (final Constructor<?> c : ResourceFactory.class.getDeclaredConstructors()) {
				c.setAccessible(true);
				c.newInstance();
			}
			Assert.fail();
		} catch (final InvocationTargetException ite) {
			if (!(ite.getCause() instanceof UnsupportedOperationException)) {
				Assert.fail();
			}
		}
		try {
			for (final Constructor<?> c : SegmentFactory.class.getDeclaredConstructors()) {
				c.setAccessible(true);
				c.newInstance();
			}
			Assert.fail();
		} catch (final InvocationTargetException ite) {
			if (!(ite.getCause() instanceof UnsupportedOperationException)) {
				Assert.fail();
			}
		}
	}


	/**
	 * 
	 */
	@Test
	public void testPoKFactory() {
		final Constructor<?> cons = PoKFactory.class.getDeclaredConstructors()[0];
		cons.setAccessible(true);
		try {
			cons.newInstance();
			Assert.fail();
		} catch (final InvocationTargetException ite) {
			// Normal
		} catch (final Exception e) {
			e.printStackTrace();
			Assert.fail();
		}

		final ResultSet res = ResourceFactory.createResource("testref", "testres", ResultSet.class);
		Assert.assertNotNull(res);
		final PieceOfKnowledge pok = PoKFactory.createAndLinkPoK(res);
		Assert.assertNotNull(pok);
		res.setUri("blablablalb:bla !");

		try {
			PoKFactory.createAndLinkPoK(res);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

	}


	/**
	 * 
	 */
	@Test
	public void testMediaUnitFactory() {
		final Document doc = new Document();
		try {
			MediaUnitFactory.createAndLinkMediaUnit(doc, MediaUnit.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}
		try {
			doc.setUri("not an uri !");
			MediaUnitFactory.createAndLinkMediaUnit(doc, Image.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

		try {
			MediaUnitFactory.createAndLinkMediaUnit(doc, DummyResource2.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

	}


	/**
	 * 
	 */
	@Test
	public void testResourceFactory() {
		try {
			ResourceFactory.createResource("none", "none", DummyResource.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

		try {
			ResourceFactory.createResource("none", "none", DummyResource2.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

	}


	/**
	 * 
	 */
	@Test
	public void testSegmentFactory() {
		try {
			SegmentFactory.createAndLinkSegment(new Document(), Segment.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkSegment(new Document(), DummySegment.class);
			Assert.fail();
		} catch (final WebLabResourceCreationException w) {
			// Normal
		}

		try {
			Document d = ResourceFactory.createResource("doc", "test", Document.class);
			TrackSegment ts = SegmentFactory.createAndLinkSegment(d, TrackSegment.class);
			ts.getSegment().add(ts);
			TrackSegment ts2 = SegmentFactory.createAndLinkSegment(d, TrackSegment.class);
			ts.getSegment().add(ts2);

			Assert.assertEquals("weblab://doc/test#2", AbstractFactory.createSegmentURIFor(d));
			Assert.assertEquals("weblab://doc/test#0-3", AbstractFactory.createSegmentURIFor(ts));

			Text text = ResourceFactory.createResource("text", "test", Text.class);

			SegmentFactory.createAndLinkLinearSegment(text, 0, 12);
			SegmentFactory.createAndLinkLinearSegment(text, 0, 12, true);
			SegmentFactory.createAndLinkLinearSegment(text, 0, 12, false);

			// SegmentFactory.createAndLinkSpatialSegment(d, new int[0]);
			SegmentFactory.createAndLinkSpatialSegment(d, new int[] { Integer.MAX_VALUE, Integer.MAX_VALUE, Integer.MIN_VALUE, Integer.MIN_VALUE });

			SegmentFactory.createAndLinkSpatioTemporalSegment(d, 0, new int[] { Integer.MAX_VALUE, Integer.MAX_VALUE, Integer.MIN_VALUE, Integer.MIN_VALUE });

			SegmentFactory.createAndLinkTemporalSegment(d, 0, 1);
			SegmentFactory.createAndLinkTemporalSegment(d, 0, 1, true);
			SegmentFactory.createAndLinkTemporalSegment(d, 0, 1, false);


		} catch (final WebLabResourceCreationException w) {
			Assert.fail();
		}

		try {
			SegmentFactory.createAndLinkLinearSegment((Text) null, 0, 12);
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}
		try {
			SegmentFactory.createAndLinkLinearSegment(new Text(), 12, 0);
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkSpatialSegment((Text) null, new int[] { Integer.MAX_VALUE, Integer.MAX_VALUE, Integer.MIN_VALUE, Integer.MIN_VALUE });
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkSpatialSegment(new Document(), null);
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkSpatialSegment(new Document(), new int[] {});
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkSpatialSegment(new Document(), new int[] { 0 });
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkSpatialSegment(new Document(), new int[] { 0, 1 });
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkSpatialSegment(new Document(), new int[] { 0, 1, -2 });
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkTemporalSegment((Text) null, 0, 1);
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}

		try {
			SegmentFactory.createAndLinkTemporalSegment(new Document(), 1, 0);
			Assert.fail();
		} catch (final WebLabUncheckedException w) {
			// Normal
		}
	}

}
