/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.LogFactory;
import org.ow2.weblab.core.extended.exception.WebLabUncheckedException;
import org.ow2.weblab.core.helper.BeanHelper;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.xml.XmlBeanFactory;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;

/**
 * Handle an <code>XmlBeanFactory</code> as defined in the Spring framework.
 * 
 * @author EADS WebLab Team
 * @date 2007-08-29
 */
@Deprecated
public class BeanHelperImpl extends BeanHelper {


	/**
	 * The current bean factory to be used.
	 */
	private volatile static XmlBeanFactory currentFactory;


	/**
	 * The current file path to the bean configuration file.
	 */
	private volatile static String currentFile;


	/**
	 * To prevent from reconstruct the factories each time, we let a <code>Map</code>.
	 */
	final private static Map<String, XmlBeanFactory> factories = new HashMap<String, XmlBeanFactory>();


	/**
	 * The default configuration file to be used.
	 */
	public static final String CONF_FILE = "beans.xml";


	/**
	 * The default constructor Instantiate the current factory using the configuration file <code>CONF_FILE</code>, and add it to the newly created map. If
	 * <code>CONF_FILE</code> is not accessible in classpath, the error is logged but nothing is done.
	 */
	public BeanHelperImpl() {
		LogFactory.getLog(this.getClass()).info("Starting with the configuration file: " + BeanHelperImpl.CONF_FILE);
		try {
			final Resource resource = new ClassPathResource(BeanHelperImpl.CONF_FILE);
			if (resource.exists()) {
				try {
					final String file = resource.getFile().getAbsolutePath();
					BeanHelperImpl.currentFactory = new XmlBeanFactory(resource);
					BeanHelperImpl.currentFile = file;
					BeanHelperImpl.factories.put(file, BeanHelperImpl.currentFactory);
				} catch (final IOException ioe) {
					// Not adding it is not really a problem
					LogFactory.getLog(this.getClass()).debug("Unable to get path to file used for the factory (" + BeanHelperImpl.CONF_FILE + ").", ioe);
				}
			} else {
				LogFactory.getLog(this.getClass()).debug("Unable to load default configuration file: (" + BeanHelperImpl.CONF_FILE + ").");
			}
		} catch (final BeansException be) {
			BeanHelperImpl.currentFactory = null;
			BeanHelperImpl.currentFile = null;
			LogFactory.getLog(this.getClass()).warn("Cannot load " + "the default file: " + BeanHelperImpl.CONF_FILE, be);
		}
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see org.weblab_project.core.helper.BeanFactory#getSpecificInstance(java.lang.String)
	 */
	@Override
	public BeanHelper getSpecificInstance(final String path) {
		final File file = new File(path);
		if (!file.exists()) {
			throw new WebLabUncheckedException("Cannot load the file at path: " + path);
		}
		final String absPath = file.getAbsolutePath();

		if (BeanHelperImpl.factories.containsKey(absPath)) {
			BeanHelperImpl.currentFactory = BeanHelperImpl.factories.get(absPath);
			BeanHelperImpl.currentFile = absPath;
		} else {
			try {
				BeanHelperImpl.currentFactory = new XmlBeanFactory(new FileSystemResource(file));
			} catch (final BeansException be) {
				throw new WebLabUncheckedException("Cannot load the file at path: " + absPath, be);
			}
			BeanHelperImpl.currentFile = absPath;
			BeanHelperImpl.factories.put(absPath, BeanHelperImpl.currentFactory);
		}
		return BeanHelper.getInstance();
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see org.weblab_project.core.helper.BeanFactory#getBean(java.lang.String, java.lang.Class)
	 */
	@Override
	public <T> T getBean(final String name, final Class<T> beanClass) {
		if (!this.isBeanDefined(name, beanClass)) {
			throw new WebLabUncheckedException("Bean '" + name + "' of type '" + beanClass.getName() + "' is not defined in file: "
					+ BeanHelperImpl.currentFile + ".");
		}
		T res = null;
		final Object o = BeanHelperImpl.currentFactory.getBean(name, beanClass);
		if (beanClass.isInstance(o)) {
			res = beanClass.cast(o);
		} else {
			throw new WebLabUncheckedException("Unable to cast " + "the loaded bean " + name + " into a " + beanClass.getName());
		}
		return res;
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see org.weblab_project.core.helper.BeanFactory#getSpecificInstance(java.lang.String, boolean)
	 */
	@Override
	public BeanHelper getSpecificInstance(final String fileNameOrPath, final boolean name) {
		String path;
		if (name) {
			final Resource res = new ClassPathResource(fileNameOrPath);
			try {
				path = res.getFile().getAbsolutePath();
			} catch (final IOException ioe) {
				LogFactory.getLog(this.getClass()).warn("Error accessing file: " + fileNameOrPath);
				path = fileNameOrPath;
				// We let it go, it will break in getSpecificInstance(String)
			}
		} else {
			path = fileNameOrPath;
		}
		return this.getSpecificInstance(path);
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see org.weblab_project.core.helper.BeanFactory#isBeanDefined(java.lang.String, java.lang.Class)
	 */
	@Override
	public boolean isBeanDefined(final String name, final Class<?> beanClass) {
		if (BeanHelperImpl.currentFactory.containsBean(name)) {
			final Class<?> theClass = BeanHelperImpl.currentFactory.getType(name);
			if (beanClass.isAssignableFrom(theClass)) {
				return true;
			}
		}
		return false;
	}
}