/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.io.File;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.impl.Rule.Domain;
import org.ow2.weblab.core.helper.test.ResourcesCreator;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.Document;

import com.hp.hpl.jena.graph.Node;
import com.hp.hpl.jena.graph.Triple;

public class ComplexTripleSelectorTest extends TestCase {

	public void testComplexSelector() {
		ResourcesCreator.buildTestResources();
		final ComplexTripleSelector cts = new ComplexTripleSelector();
		final String sujet = "itm:n#_100282";
		final String predicat = RDF.TYPE;
		final String objet = "http://www.weblab-project.org/ontologies/stanag2433.owl#Event";
		cts.addPORule(predicat, objet);
		cts.addSORule(sujet, objet);
		cts.addSPRule(sujet, predicat);

		try {
			final Annotation annotation = new WebLabMarshaller().unmarshal(new File("src/test/resources/annotation.xml"), Annotation.class);
			Assert.assertEquals(2, cts.findInResource(annotation, null, null, null).size());
			Assert.assertEquals(1, cts.searchFor(annotation).size());
			final Document doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/document.xml"), Document.class);

			final Rule rule1 = new Rule(Domain.OBJECT, "empty", Domain.SUBJECT, "empty");
			final Rule rule2 = new Rule(Domain.OBJECT, "empty", null, null);
			final ComplexTripleSelector filter = new ComplexTripleSelector();
			filter.addRule(rule1);
			Assert.assertEquals(2, filter.findInResource(annotation, null, null, null).size());
			final ComplexTripleSelector filter2 = new ComplexTripleSelector();
			filter2.addRule(rule2);
			Assert.assertEquals(47, filter2.findInResource(doc, null, null, null).size());
			filter2.limitToFirstLevelAnnotation(true);
			Assert.assertEquals(47, filter2.findInResource(doc, null, null, null).size());
			final TripleSelectors ts = new TripleSelectors();
			Assert.assertEquals(2, ts.findInResource(annotation, null).size());


		} catch (final WebLabCheckedException e) {
			e.printStackTrace();
			Assert.fail(e.getMessage());
		}
	}


	public void testComplexFactory() {
		final RDFRulesSelector rrs1 = RDFSelectorFactory.getSelectorByRules(true, "http://org.weblab-projects/test");
		try {
			final Annotation annotation = new WebLabMarshaller().unmarshal(new File("src/test/resources/annotation.xml"), Annotation.class);

			rrs1.addSPRule(".*", ".*");
			rrs1.addPORule(".*", ".*");
			rrs1.addSORule(".*", ".*");
			Assert.assertEquals(2, rrs1.findIn(annotation).size());

			final Rule rule1 = new Rule(Domain.OBJECT, "empty", Domain.SUBJECT, "empty");
			final Rule rule2 = new Rule(Domain.OBJECT, "empty", null, null);
			((ComplexTripleSelector) rrs1).rules.add(rule2);
			Assert.assertTrue(((ComplexTripleSelector) rrs1).matches(rule2,
					new Triple(Node.createURI("empty"), Node.createURI("test"), Node.createURI("empty"))));

			Assert.assertEquals("{OBJECT:empty, SUBJECT:empty}", rule1.toString());

			final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
			Statements wm = rs.searchFor(annotation);
			Assert.assertEquals(187, wm.toString().length());
			wm = rs.searchFor(annotation, "weblab://property/test");
			Assert.assertEquals(0, wm.size());
			final ComposedResource rc = new ComposedResource();
			rc.setUri("weblab://test/test");
			rc.getResource().add(annotation);

			Assert.assertNull(wm.getResource("weblab://test/test"));
			Assert.assertNull(wm.getAnnotatedResourceWith(annotation.getUri()));

		} catch (final WebLabCheckedException e) {
			e.printStackTrace();
			Assert.fail(e.getMessage());
		}

	}


	public void testReifComplexSelector() {
		final AdvancedSelector rdfs = RDFSelectorFactory.getSelector(true, "http://marshmalow.gum.net/ontology#");
		try {
			final Document doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/document.xml"), Document.class);
			final Statements wm = rdfs.searchFor(doc, "http://weblab-project.org/core/model/property/processing/temp/luxid/type",
					"http://weblab-project.org/core/model/property/processing/temp/luxid/meta", RDF.PREDICATE, RDF.OBJECT, RDF.SUBJECT, RDF.TYPE, RDFS.LABEL);
			Assert.assertEquals(2, wm.size());
		} catch (final WebLabCheckedException e) {
			e.printStackTrace();
			Assert.fail(e.getMessage());
		}
	}

}
