/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.io.File;
import java.util.List;
import java.util.Set;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.impl.parser.Parsers;
import org.ow2.weblab.core.helper.impl.parser.ReflectChanger;
import org.ow2.weblab.core.model.Document;

public class ResultsTest extends TestCase {


	public void testResults() {
		this.resetParsers();

		try {
			final Document document = new WebLabMarshaller().unmarshal(new File("src/test/resources/document.xml"), Document.class);
			SimpleSelector simpleSelector = RDFSelectorFactory.getSelector();
			Results results = simpleSelector.select(document);
			Assert.assertEquals(2, results.size());
			Set<String> uris = results.getSubjects(RDF.TYPE, null);
			Assert.assertEquals(1, uris.size());
			uris = results.getSubjects(null, null);
			Assert.assertEquals(2, uris.size());

			// Integer size = results.getTypedValue("weblab://fileRepository/1236093700390/res_603",
			// "http://weblab-project.org/core/model/property/hasOriginalFileSize" , Integer.class);
			// assertEquals(4404, size.intValue());

			List<String> values = results.getTypedValues(null, RDFS.LABEL, String.class);
			Assert.assertEquals(46, values.size());

			simpleSelector = RDFSelectorFactory.getSelector("weblab://test");
			simpleSelector.limitToFirstLevelAnnotation(true);
			results = simpleSelector.select(document);
			Assert.assertEquals(2, results.size());

			final Results r = new Results(results.statements);
			values = r.getTypedValues(null, RDFS.LABEL, String.class);
			Assert.assertEquals(46, values.size());

		} catch (final WebLabCheckedException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			Assert.fail();
		}
	}


	public void resetParsers() {
		final Object result = ReflectChanger.invoke(null, Parsers.class, "loadParsers", true, new Object[0]);
		ReflectChanger.setField(null, Parsers.class, "parsers", result, true);
	}

}
