/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.io.File;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.List;

import junit.framework.TestCase;

import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.extended.ontologies.WebLab;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.Resource;


public class SelectorTest extends TestCase {


	public void testAnnots() {
		try {
			new URI("");
		} catch (final URISyntaxException e1) {
			// TODO Auto-generated catch block
			// e1.printStackTrace();
		}

		final AdvancedSelector as = RDFSelectorFactory.getSelector(true, "http://www.weblab-project.org/ontologies/stanag2433.owl");
		try {
			final Annotation doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/toto.xml"), Annotation.class);
			// SelectAll
			long l = System.currentTimeMillis();
			final List<WTriple> list = as.findInResource(doc, null, null, "http://www.weblab-project.org/ontologies/stanag2433.owl#Event");
			// Do something fun with WTriples ...
			l = System.currentTimeMillis() - l;
			// System.out.println(list);
			// System.err.println(l+" ms");

			// return l;
		} catch (final WebLabCheckedException e) {
			// TODO Auto-generated catch block
			// e.printStackTrace();
		}
	}


	public void testFilterAnnots() {
		final AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		try {
			final Filter f = new Filter();
			f.addPOFilter(".*", "Sierra.*");

			final Document doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/BIG.xml"), Document.class);
			// SelectAll
			long l = System.currentTimeMillis();
			final List<WTriple> list = as.findInResource(doc, f);
			l = System.currentTimeMillis() - l;
			// System.err.println(l+" ms");
			// System.out.println(list.size());
			// Do something fun with WTriples ...
			// return l;
		} catch (final WebLabCheckedException e) {
			// TODO Auto-generated catch block
			// e.printStackTrace();
		}
		// return -1;
	}


	public void testStanag() {
		final AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		try {
			final Filter f = new Filter();
			f.addPOFilter(".*stanag.*", ".*");

			final Document doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/input.xml"), Document.class);

			long l = System.currentTimeMillis();
			final List<WTriple> list = as.findInResource(doc, f);
			l = System.currentTimeMillis() - l;
			// System.err.println(l+" ms");
			// System.out.println(list.size());
			// for(WTriple wt:list){
			// System.out.println(wt);
			// }
		} catch (final WebLabCheckedException e) {
			// e.printStackTrace();
		}

	}


	/**
	 * Rebuild entities from RDF
	 */
	public void testWTripleMap() {
		final AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		try {
			final ComposedResource doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/retour.xml"), ComposedResource.class);
			long l = System.currentTimeMillis();
			final Statements map = as.searchFor(doc, "http://www.weblab-project.org/ontologies/stanag2433.owl#e-eTime_startDateTime",
					"http://www.weblab-project.org/ontologies/stanag2433.owl#e-eTime_endDateTime");
			l = System.currentTimeMillis() - l;
			// System.err.println(l+" ms");
			// System.out.println(map.size());
			// System.out.println(map);
			// for(String s:map.keySet()){
			// Map<String,String> preds = map.get(s);
			// System.out.println(s+" :");
			// for(String pred:preds.keySet()){
			// System.out.println(pred+" "+preds.get(pred));
			// }
			// }
		} catch (final WebLabCheckedException e) {
			// e.printStackTrace();
		}

	}


	/**
	 * Test for a list of values support
	 */
	public void testMultiResult() {
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		try {
			final ComposedResource rc = new WebLabMarshaller().unmarshal(new File("src/test/resources/personRDFResult.xml"), ComposedResource.class);
			final Statements wtm = rs.searchFor(rc);
			// System.out.println(wtm);
			// System.out.println(wtm.get("itm:n#_100294").get("http://www.w3.org/2000/01/rdf-schema#label"));
		} catch (final WebLabCheckedException e) {
			// e.printStackTrace();
		}
	}


	public void testSearchResult() {
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		try {
			final ComposedResource rc = new WebLabMarshaller().unmarshal(new File("src/test/resources/search_result.xml"), ComposedResource.class);
			final Statements wtm = rs.searchFor(rc, "http://weblab-project.org/core/model/property/hasNumberOfResults");
			// System.out.println(wtm);

		} catch (final WebLabCheckedException e) {
			// e.printStackTrace();
		}
	}


	public void testSearchResult2() {
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		try {
			final ComposedResource rc = new WebLabMarshaller().unmarshal(new File("src/test/resources/resource_search.xml"), ComposedResource.class);
			final String[] preds = new String[] { "http://weblab-project.org/core/model/1.0/property/extracted/concept/visual",
					"http://purl.org/dc/elements/1.1/title", "http://purl.org/dc/elements/1.1/creator", "http://purl.org/dc/elements/1.1/subject",
					"http://purl.org/dc/elements/1.1/description", "http://purl.org/dc/elements/1.1/date", "http://purl.org/dc/elements/1.1/language",
					"http://purl.org/dc/elements/1.1/publisher", "http://purl.org/dc/elements/1.1/contibutor", "http://purl.org/dc/elements/1.1/type",
					"http://purl.org/dc/elements/1.1/format", "http://purl.org/dc/elements/1.1/identifier", "http://purl.org/dc/elements/1.1/source",
					"http://purl.org/dc/elements/1.1/relation", "http://purl.org/dc/elements/1.1/coverage", "http://purl.org/dc/elements/1.1/right",
					"http://weblab-project.org/core/model/1.0/property/hasNativeContent",
					"http://weblab-project.org/core/model/1.0/property/hasNormalisedContent",
					"http://weblab-project.org/core/model/1.0/property/isGeneratedFrom", "http://weblab-project.org/core/model/1.0/property/isProducedFrom",
					"http://weblab-project.org/core/model/1.0/property/isResultOf", "http://weblab-project.org/core/model/1.0/property/hasHitScore",
					"http://weblab-project.org/core/model/1.0/property/hasNumberOfResults", "http://weblab-project.org/core/model/1.0/property/isExposedAs",
					"http://purl.org/dc/terms/extent", "http://purl.org/dc/terms/modified", "http://purl.org/dc/terms/created",
					"http://weblab-project.org/core/model/1.0/property/hasCrawlingDate", };

			final Statements wtm = rs.searchFor(rc, preds);
			// System.out.println(wtm);

		} catch (final WebLabCheckedException e) {
			// e.printStackTrace();
		}
	}


	public void testFilter() throws WebLabCheckedException {
		// WTriple w1 = new WTriple("weblab://candidateInstance/1237816804656/event48","http://www.w3.org/2000/01/rdf-schema#label","Makeni",null, null);
		// WTriple w2 = new WTriple("weblab://candidateInstance/1237816804656/event48","http://www.w3.org/2000/01/rdf-schema#label","Makeni",null, null);
		//
		// HashSet<WTriple> s = new HashSet<WTriple>();
		// s.add(w1);
		// s.add(w2);
		// System.out.println(s.size());
		// System.exit(0);

		final String GEONAMES = "http://www.geonames.org/ontology/Feature";
		final Filter filter = new Filter();
		filter.addPOFilter(RDF.TYPE, "http://www.weblab-project.org/ontologies/stanag2433.owl#Event");
		filter.addPOFilter("http://www.weblab-project.org/ontologies/stanag2433.owl#e-eLoc_geographicLocationData", ".*");
		filter.addPOFilter(GEONAMES, ".*");
		filter.addPOFilter(WebLab.REFERS_TO, ".*");
		filter.addPOFilter(RDFS.LABEL, ".*");
		filter.addPOFilter("http://www.opengis.net/gml/_Feature/Latitude", ".*");
		filter.addPOFilter("http://www.opengis.net/gml/_Feature/Longitude", ".*");

		final Document doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/document.xml"), Document.class);

		final Statements wtm = new Statements();
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		long l = System.currentTimeMillis();
		final List<WTriple> wl = rs.findInResource(doc, filter);
		wtm.addAll(wl);
		l = System.currentTimeMillis() - l;
		// System.out.println(wtm+"\n"+l+"ms\nfor "+wtm.size()+" elts.");
		// for(WTriple wt:wl){
		// Resource r = wt.getSubjectResource();
		// if (r instanceof Document){
		// System.out.println(wt);
		// }
		// }
		// System.out.println("BAM !"+doc.getUri()+"\n"+wl.size());
	}


	public void testNotReif() throws WebLabCheckedException {
		final Document doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/document.xml"), Document.class);

		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		rs.findInResource(doc, null, RDF.TYPE, null, false);
		rs.findInResource(doc, null, RDF.TYPE, null, true);

	}


	public void testNullData() {
		final Resource r = new Resource();
		// Segment s = new Segment(){};
		final Annotation a = new Annotation();
		r.getAnnotation().add(a);

		final TripleSelectors ts = new TripleSelectors(true);
		ts.findInResource(r, null, null, null);

		// a.setData(null);
		// s.getAnnotation().add(a);
		// ts.findInResource(s, null, null, null);
		//
		// ComposedResource rc = new ComposedResource();
		// rc.getResource().add(s);
		//
		// ts.findInResource(s, null, null, null);

	}


	private Document loadDoc() {
		try {
			// big one
			// return new WebLabMarshaller().unmarshal(new File("src/test/resources/res_345.xml"), Document.class);
			// small one
			return new WebLabMarshaller().unmarshal(new File("src/test/resources/document.xml"), Document.class);
		} catch (final WebLabCheckedException e) {
			e.printStackTrace();
		}
		return null;
	}


	public void testSimpleSelection() throws WebLabCheckedException {

		TripleSelectors.multi = false;
		final TripleSelectors ts = new TripleSelectors(true);
		this.search(ts);
	}


	private long search(TripleSelectors ts) {
		final Document doc = this.loadDoc();

		long sum = 0;
		final long time = System.currentTimeMillis();
		ts = new TripleSelectors(true);
		final List<WTriple> l = ts.findInResource(doc, null, RDF.TYPE, null);
		sum = System.currentTimeMillis() - time;
		System.out.println(sum + "ms " + l.size());

		return sum;
	}


	public void testMultiSelection() throws WebLabCheckedException {
		TripleSelectors.multi = true;
		final TripleSelectors ts = new TripleSelectors(true);
		final Runtime runtime = Runtime.getRuntime();

		final int nrOfProcessors = runtime.availableProcessors();

		System.out.println("Number of processors available to the Java Virtual Machine: " + nrOfProcessors);
		this.search(ts);

	}


	public void testConcatSelection() throws WebLabCheckedException {

		AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		final Document doc = this.loadDoc();
		as.findInResource(doc, null, RDF.TYPE, null);

		long sum = 0;
		final long time = System.currentTimeMillis();
		as = RDFSelectorFactory.getSelector(true);
		final List<WTriple> l = as.findInResource(doc, null, RDF.TYPE, null);
		sum = System.currentTimeMillis() - time;
		System.out.println(sum + "ms " + l.size());
	}
}
