/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.io.File;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.PieceOfKnowledge;

public class WTripleWrite extends TestCase {


	public void testWrite() throws WebLabCheckedException {
		final AdvancedSelector s = RDFSelectorFactory.getSelector(true, "weblab:/");
		final Document doc = new WebLabMarshaller().unmarshal(new File("src/test/resources/document.xml"), Document.class);

		final Statements wm = s.searchFor(doc);// ,
												// "http://purl.org/dc/elements/1.1/title","http://purl.org/dc/elements/1.1/format","http://purl.org/dc/elements/1.1/author");

		wm.get(doc.getUri()).writeStatement("moi://propertyiiiii", "weblab://test#test");

		final Annotation annot = new WebLabMarshaller().unmarshal(new File("src/test/resources/annotation.xml"), Annotation.class);
		final Statements wm2 = s.searchFor(annot);

		wm2.writeAndAdd(wm, annot);

		Assert.assertEquals(2, wm2.size());

	}


	public void testAddingPoKWrite() throws WebLabCheckedException {
		final AdvancedSelector s = RDFSelectorFactory.getSelector(true, "weblab:/");
		final PieceOfKnowledge pok1 = new WebLabMarshaller().unmarshal(new File("src/test/resources/annotation.xml"), PieceOfKnowledge.class);

		final Statements wm = s.searchFor(pok1);// ,
												// "http://purl.org/dc/elements/1.1/title","http://purl.org/dc/elements/1.1/format","http://purl.org/dc/elements/1.1/author");

		final PieceOfKnowledge pok2 = new WebLabMarshaller().unmarshal(new File("src/test/resources/annotation.xml"), PieceOfKnowledge.class);
		final Statements wm2 = s.searchFor(pok2);

		wm2.writeAndAdd(wm, pok1);

		Assert.assertEquals(1, wm2.size());
	}

}
