/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl.parser;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Properties;

import javax.xml.parsers.ParserConfigurationException;

import junit.framework.Assert;
import junit.framework.TestCase;

public class ParserTest extends TestCase {





	public void testParserClassCastException() {
		try {
			Parsers.getParser(String.class);
			final HashMap<String, Object> parsers = new HashMap<String, Object>();
			parsers.put("java.lang.String", "nones");
			ReflectChanger.setField(null, Parsers.class, "parsers", parsers, true);
			Parsers.getParser(String.class);
			Assert.fail();
		} catch (final ClassCastException e) {
		} catch (final ParserConfigurationException e) {
			e.printStackTrace();
			Assert.fail();
		}
	}


	public void testLoader() {
		// original system classloader
		final ClassLoader original = ClassLoader.getSystemClassLoader();
		final DummyClassLoader dummy = new DummyClassLoader(original, ".*RDFTransparentStringTypeParser");

		ReflectChanger.setSystemClassLoader(dummy);

		try {
			final Class<?> parsersClass = dummy.loadClass(" org.weblab_project.core.helper.impl.parser.Parsers");
			final Method m = parsersClass.getDeclaredMethod("getParser", Class.class);
			m.invoke(null, String.class);
			Assert.fail();
		} catch (final Exception e1) {
			e1.printStackTrace();
		}


		// reopen static load of properties
		try {
			Parsers.strict = false;
			final Method m = Parsers.class.getDeclaredMethod("loadParsers");
			m.setAccessible(true);
			m.invoke(null);
			Parsers.strict = true;
			m.invoke(null);
			dummy.dummyURLs = 1;
			m.invoke(null);
			dummy.dummyURLs = 2;
			m.invoke(null);
			dummy.dummyURLs = 0;
		} catch (final SecurityException e) {
			e.printStackTrace();
			Assert.fail();
		} catch (final NoSuchMethodException e) {
			e.printStackTrace();
			Assert.fail();
		} catch (final IllegalArgumentException e) {
			e.printStackTrace();
			Assert.fail();
		} catch (final IllegalAccessException e) {
			e.printStackTrace();
			Assert.fail();
		} catch (final InvocationTargetException e) {
			e.printStackTrace();
			Assert.fail();
		}

		ReflectChanger.setSystemClassLoader(original);

	}


	public void testLoad() {
		// reopen static load of properties
		try {
			Parsers.strict = true;
			final Method m = Parsers.class.getDeclaredMethod("load", Object.class);
			m.setAccessible(true);
			m.invoke(null, "");
			m.invoke(null, ClassLoader.class.getName());
			m.invoke(null, AbstractClass.class.getName());
		} catch (final SecurityException e) {
			e.printStackTrace();
			Assert.fail();
		} catch (final NoSuchMethodException e) {
			e.printStackTrace();
			Assert.fail();
		} catch (final IllegalArgumentException e) {
			e.printStackTrace();
			Assert.fail();
		} catch (final IllegalAccessException e) {
			e.printStackTrace();
			Assert.fail();
		} catch (final InvocationTargetException e) {
			e.printStackTrace();
			Assert.fail();
		}
	}


	abstract class AbstractClass {
	}



	public void testProp() {
		final Properties p = new Properties();
		try {
			p.load(new FileReader(new File("src/test/resources/t.properties")));
			System.out.println(p);
		} catch (final FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (final IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		// p.setProperty("test", "ts");
		// try {
		// p.storeToXML(System.out, "none");
		// } catch (IOException e) {
		// // TODO Auto-generated catch block
		// e.printStackTrace();
		// }
	}
}
