/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.test;

import java.io.File;
import java.util.Locale;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.impl.AdvancedSelector;
import org.ow2.weblab.core.helper.impl.RDFSelectorFactory;
import org.ow2.weblab.core.helper.impl.Statements;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ResultSet;

public class LangTest extends TestCase {


	public void testLangRDFSpec() throws WebLabCheckedException {
		final File annot = new File("src/test/resources/annotation.xml");
		if (!annot.exists()){
			ResourcesCreator.buildTestResources();
		}
		
		final Annotation a = new WebLabMarshaller().unmarshal(annot, Annotation.class);

		final AdvancedSelector rdfs = RDFSelectorFactory.getSelector(true);
		final Statements m = rdfs.searchFor(a);
		// m.getFirstValue(subject,predicat,Locale.CANADA_FRENCH.)
		Assert.assertEquals("empty", m.getFirstValue(null, RDFS.LABEL, Locale.FRENCH));
		Assert.assertTrue(m.getFirstValue(null, RDFS.LABEL, null) != null);

		// System.out.println(l.equals(Locale.FRENCH)+" "+l.toString());
	}


	public void testLangBuggyRS() throws WebLabCheckedException {
		final File resultset = new File("src/test/resources/resultSet.xml");
		
		if (!resultset.exists()){
			ResourcesCreator.buildTestResources();
		}
		
		final ResultSet a = new WebLabMarshaller().unmarshal(resultset, ResultSet.class);

		final AdvancedSelector rdfs = RDFSelectorFactory.getSelector(true);
		final Statements m = rdfs.searchFor(a);
		Assert.assertNull(m.getFirstValue(null, RDFS.LABEL, Locale.ENGLISH));
		// System.out.println();

	}
}
