/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.test;

import java.io.File;
import java.util.List;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.impl.AdvancedSelector;
import org.ow2.weblab.core.helper.impl.RDFSelectorFactory;
import org.ow2.weblab.core.helper.impl.Statements;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.ResultSet;

public class SortedTest extends TestCase {


	public void testMultiResult() {
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		try {
			final ComposedResource rc = new WebLabMarshaller().unmarshal(new File("src/test/resources/bugfix/test.xml"), ComposedResource.class);
			final Statements wtm = rs.searchFor(rc);
			List<String> luri = wtm.sortBy(RDFS.LABEL, Statements.ASC);
			Assert.assertTrue((luri.size() == 2) && luri.get(0).equals("itm:n#_100282"));
			luri = wtm.sortBy(RDFS.LABEL, Statements.DESC);
			Assert.assertTrue((luri.size() == 2) && luri.get(0).equals("itm:n#_100283"));
		} catch (final WebLabCheckedException e) {
			e.printStackTrace();
		}
	}


	public void testMultiResultFiltered() {
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		try {
			final ResultSet rset = new WebLabMarshaller().unmarshal(new File("src/test/resources/bugfix/test.xml"), ResultSet.class);
			final Statements wtm = rs.searchFor(rset);
			List<String> luri = wtm.sortBy(RDFS.LABEL, Statements.ASC, true);
			Assert.assertTrue(luri.size() == 3);
			Assert.assertEquals("itm:n#_100282", luri.get(0));
			Assert.assertEquals("itm:n#_100284", luri.get(2));

			luri = wtm.sortBy(RDFS.LABEL, Statements.DESC, true);
			Assert.assertTrue(luri.size() == 3);
			Assert.assertEquals("itm:n#_100283", luri.get(0));
			Assert.assertEquals("itm:n#_100284", luri.get(2));
			//
			// for(String uri:luri){
			// System.out.println(wtm.get(uri).get("http://weblab-project.org/core/model/property/hasIndex"));
			// wtm.getResource(uri);
			// }

			// luri = wtm.sortBy("http://www.w3.org/2000/01/rdf-schema#label", WTripleMap.DESC);

			// System.out.println(wtm);
		} catch (final WebLabCheckedException e) {
			e.printStackTrace();
		}
	}
}
