/**
* WEBLAB: Service oriented integration platform for media mining and intelligence applications
*  
* Copyright (C) 2004 - 2011 Cassidian, an EADS company
* 
* This library is free software; you can redistribute it and/or modify it under the terms of
* the GNU Lesser General Public License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
* 
* This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
* See the GNU Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public License along with this
* library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
* Floor, Boston, MA 02110-1301 USA
*/

package org.ow2.weblab.core.helper.impl;

import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.w3c.dom.Node;
import org.xml.sax.SAXParseException;

import com.hp.hpl.jena.rdf.arp.DOM2Model;
import com.hp.hpl.jena.rdf.model.Model;
import com.hp.hpl.jena.rdf.model.ModelFactory;

/**
 * A fast Jena model loader for WebLab resources, based on DOM, that extends 
 * JenaResourceStructureHelperExtended. Using DOM object to add PieceOfKnowledge 
 * in Jena model is above 30% faster than using String and indentation of the
 * PoKUtil getPokData method.
 * 
 * @author emilienbondu
 *
 */
public class FastResourceToJenaModel extends JenaResourceStructureHelperExtended {

	/**
	 * The default constructor.
	 */
	public FastResourceToJenaModel() {
		super();
	}
	
	/**
	 * Constructor on the WebLab resource. 
	 * @param resource
	 */
	public FastResourceToJenaModel(Resource resource) {
		this.setResource(resource);
	}

	@Override
	protected void addPieceOfKnowledge(final PieceOfKnowledge p) {
		Object o = p.getData();
		if (o != null) {
		 final Model model = ModelFactory.createDefaultModel();
	      try {
	          final DOM2Model dm = DOM2Model.createD2M(RDF.NAMESPACE, model);
	          dm.load(((Node) o).getFirstChild());
	          dm.close();
	      } catch (SAXParseException e) {
	          e.printStackTrace();
	      }
	      this.bejh.addToModel(model);
		}
	}
}
