/**
* WEBLAB: Service oriented integration platform for media mining and intelligence applications
*  
* Copyright (C) 2004 - 2011 Cassidian, an EADS company
* 
* This library is free software; you can redistribute it and/or modify it under the terms of
* the GNU Lesser General Public License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
* 
* This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
* See the GNU Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public License along with this
* library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
* Floor, Boston, MA 02110-1301 USA
*/

package org.ow2.weblab.core.helper.impl;

import java.io.File;

import junit.framework.TestCase;

import org.ow2.weblab.core.extended.factory.AnnotationFactory;
import org.ow2.weblab.core.extended.factory.LowLevelDescriptorFactory;
import org.ow2.weblab.core.extended.factory.ResourceFactory;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.helper.PoKHelper;
import org.ow2.weblab.core.helper.RDFHelperFactory;
import org.ow2.weblab.core.helper.ResourceHelper;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.Audio;
import org.ow2.weblab.core.model.ComposedQuery;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.ElementaryQuery;
import org.ow2.weblab.core.model.LowLevelDescriptor;
import org.ow2.weblab.core.model.MediaUnit;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Query;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.core.model.Segment;
import org.ow2.weblab.core.model.SimilarityQuery;
import org.ow2.weblab.core.model.SpatialSegment;
import org.ow2.weblab.core.model.StringQuery;
import org.ow2.weblab.core.model.TemporalSegment;
import org.ow2.weblab.core.model.Text;


/**
 */
public class JenaResourceStructureHelperTest extends TestCase {

	/**
	 * @throws Exception
	 */
	@SuppressWarnings("serial")
	public void testAddResourcesTest() throws Exception {
		// Empty objects

		Resource resource = new Resource();
		resource.setUri("weblab://test/entity");
		Annotation annot = AnnotationFactory.createAndLinkAnnotation(resource);

		ComposedResource rc = new ComposedResource();
		rc.setUri("weblab://test/entity/rc");
		LowLevelDescriptor lld = LowLevelDescriptorFactory.createAndLinkLowLevelDescriptor(resource);

		Annotation annot2 = AnnotationFactory.createAndLinkAnnotation(resource);
		PoKHelper ah = RDFHelperFactory.getPoKHelper(annot2);
		ah.createLitStat("all://your#bases", "are://belong#to", "me");

		PieceOfKnowledge onto = new PieceOfKnowledge();
		onto.setData(annot2.getData());

		PieceOfKnowledge ontovide = new PieceOfKnowledge();
		TemporalSegment ts = new TemporalSegment();
		SpatialSegment ss = new SpatialSegment();
		SegmentM sm = new SegmentM();
		StringQuery ftq = new StringQuery();
		SimilarityQuery siq = new SimilarityQuery();
		ComposedQuery cq = new ComposedQuery();
		Query q = new Query() {
			//
		};
		ElementaryQuery eq = new ElementaryQuery() {
			//
		};
		Text text = new Text();
		Audio au = new Audio();
		MediaUnitM mum = new MediaUnitM();

		rc.getResource().add(lld);
		rc.getResource().add(annot);
		rc.getResource().add(resource);
		rc.getResource().add(onto);
		rc.getResource().add(ontovide);
		rc.getResource().add(ftq);
		rc.getResource().add(siq);
		rc.getResource().add(cq);
		rc.getResource().add(q);
		rc.getResource().add(mum);
		rc.getResource().add(au);
		rc.getResource().add(text);
		rc.getResource().add(new ResourceR());
		rc.getResource().add(eq);

		int i = 0;
		for (Resource r : rc.getResource()) {
			if (r.getUri() == null) {
				r.setUri("weblab://test/entity/r" + i++);
			}
			RDFHelperFactory.getResourceHelper(r);
		}
		RDFHelperFactory.getResourceHelper(rc);

		// A WebLab Object
		WebLabMarshaller wm = new WebLabMarshaller();
		Annotation fullannot;
		fullannot = wm.unmarshal(new File("src/test/resources/annot1.xml"), Annotation.class);
		
		ComposedResource cu = ResourceFactory.createResource("ref", "res", ComposedResource.class);
		cu.getAnnotation().add(annot);

		ResourceHelper rha = RDFHelperFactory.getSpecificResourceHelperExtended(fullannot, JenaResourceStructureHelperExtended.class.getName());
		if (!(rha instanceof JenaResourceStructureHelperExtended)) {
			fail("Bad instantiation for ResourceHelper : " + rha);
		}

		ResourceHelper rhc = RDFHelperFactory.getSpecificResourceHelperExtended(cu, JenaResourceStructureHelperExtended.class.getName());
		if (!(rhc instanceof JenaResourceStructureHelperExtended)) {
			fail("Bad instantiation for ResourceHelper : " + rhc);
		}

	}

	@SuppressWarnings("serial")
	class MediaUnitM extends MediaUnit {
		//
	}

	@SuppressWarnings("serial")
	class SegmentM extends Segment {
		//
	}

	@SuppressWarnings("serial")
	class ResourceR extends Resource {
		//
	}
}
