/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.Locale;
import java.util.Properties;

import junit.framework.Assert;

import org.junit.Test;
import org.ow2.weblab.core.extended.factory.AnnotationFactory;
import org.ow2.weblab.core.extended.factory.MediaUnitFactory;
import org.ow2.weblab.core.extended.factory.ResourceFactory;
import org.ow2.weblab.core.extended.ontologies.DublinCore;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.Image;

/**
 */
public class HelperFactoryTest {


	@Test
	public void testPoKHelper() throws Exception {

		final PoKHelper ahelper = RDFHelperFactory.getPoKHelper(new Annotation());

		final Properties props = new Properties();
		final FileInputStream fis = new FileInputStream("src/test/resources/helperTest.properties");
		try {
			props.load(fis);
		} finally {
			try {
				fis.close();
			} catch (final IOException ioe) {
				// Do nothing
			}
		}

		Assert.assertEquals(props.get(PoKHelper.class.getSimpleName().toLowerCase(Locale.ENGLISH)), ahelper.getClass().getName());

	}


	/**
	 */
	@Test
	public void testComplexDocument() {
		final Document doc = ResourceFactory.createResource("formatted", "demo_0", Document.class);

		final Annotation metadata = AnnotationFactory.createAndLinkAnnotation(doc);

		PoKHelper metadataHelper = RDFHelperFactory.getPoKHelper(metadata);

		metadataHelper.createLitStat(doc.getUri(), DublinCore.SOURCE_PROPERTY_NAME, "http://server.vitalas.org/belga/pictures/07704541.jpg");

		metadataHelper.createLitStat(doc.getUri(), "http://weblab.eads.com/property/capturedate", "20080124-15:39:54");

		final Image image = MediaUnitFactory.createAndLinkMediaUnit(doc, Image.class);
		// image
		// .setContent("http://server.vitalas.org/belga/pictures/07704541.jpg");

		metadataHelper = RDFHelperFactory.getPoKHelper(AnnotationFactory.createAndLinkAnnotation(image));

		metadataHelper.createLitStat(doc.getUri(), "http://weblab.eads.com/property/metadata/iptc/creator", "LIEVEN VAN ASSCHE");
		metadataHelper.createLitStat(doc.getUri(), "http://weblab.eads.com/property/metadata/iptc/creationdate", "20080124-15:39:54");
		metadataHelper.createLitStat(doc.getUri(), "http://weblab.eads.com/property/metadata/iptc/description", "20071021 - ANTWERP, BELGIUM: Johan Vande"
				+ " Lanotte (2ndL) during the chairman elections " + "of Flemish socialist party sp.a, Sunday 21 "
				+ "October 2007 in Antwerp. Caroline Gennez (R) " + "succeeds Johan Vande Lanotte who resigned "
				+ "after the poor sp.a results for the federal " + "elections of June 2007. BELGA PHOTO LIEVEN " + "VAN ASSCHE");

	}
}
