/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl;

import java.io.File;
import java.util.Set;

import junit.framework.Assert;

import org.junit.Before;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.DublinCore;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.extended.util.PoKUtil;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;

/**
 */
public class JenaResourceHelperTest {


	private JenaResourceHelper helper;


	private Resource res;


	@Before
	public void setUp() throws Exception {
		this.helper = new JenaResourceHelper();
		this.res = new WebLabMarshaller().unmarshal(new File("src/test/resources/res.xml"), Resource.class);
		this.helper.setResource(this.res);
	}


	@Test
	public void testSimpleResourceAccess() throws Exception {

		final PieceOfKnowledge o = new PieceOfKnowledge();
		o.setUri("weblab://ert/l");
		final Annotation a = new Annotation();
		a.setUri("weblab://ert/lssdfsdfsdfsdf");
		PoKUtil.setPoKData(a, "");
		o.setData(a.getData());
		this.helper.addResource(o);
		PoKUtil.setPoKData(
				a,
				"<rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:j.0=\"http://purl.org/dc/elements/1.1/\" xmlns:j.1=\"http://purl.org/dc/terms/\" xmlns:j.2=\"http://weblab-project.org/core/model/1.0/property/\">"
						+ "  <rdf:Description rdf:about=\"weblab://IRTcrawler/070906AKMM00117_20070907_083108_240\">"
						+ "			    <j.2:isExposedAs>http://193.96.226.190/070906AKMM00117_20070907_083108_240.mp4</j.2:isExposedAs>"
						+ "			    <j.1:created>2009-01-28T12:19:40</j.1:created>" + "			  </rdf:Description>" + "			</rdf:RDF>");
		o.setData(a.getData());
		this.helper.addResource(o);

		final ComposedResource collec = new ComposedResource();
		collec.setUri("weblab://ert/lsdf");
		this.helper.addResource(collec);
	}


	@Test
	public void testResourceAccess() throws Exception {
		this.res = new WebLabMarshaller().unmarshal(new File("src/test/resources/res.xml"), Resource.class);
		this.helper.setResource(this.res);
		this.helper.setResource(this.res); // yes 2 times !
		final Document r = ((Document) this.res);
		Assert.assertEquals(this.res, this.helper.getResource());
		Assert.assertEquals(this.res, this.helper.getResource(this.res.getUri()));
		Assert.assertEquals(r, this.helper.getResource(r.getUri()));
		Assert.assertEquals(r, this.helper.getSpecificResource(r.getUri(), Document.class));
		Assert.assertEquals(Document.class, this.helper.getType(r.getUri()));
		try {
			Assert.assertEquals(this.res, this.helper.getResource(this.res.getUri() + "wfsdmvklhj<dkjsvh;whf"));
			this.helper.getSpecificResource(r.getUri() + "dmklfjgdfkg", Document.class);
			Assert.fail();
		} catch (final WebLabCheckedException e) {
			Assert.assertTrue(true);
		}
	}


	/**
	 * 
	 */
	@Test
	public void testGetPred() {
		Assert.assertEquals(4, this.helper.getPreds().size());
	}


	/**
	 * 
	 */
	@Test
	public void testGetSubjs() {
		Assert.assertEquals(1, this.helper.getSubjs().size());
	}


	/**
	 * 
	 */
	@Test
	public void testGetSubjsOnPred() {
		Assert.assertEquals(1, this.helper.getSubjsOnPred(DublinCore.TITLE_PROPERTY_NAME).size());
	}


	/**
	 * 
	 */
	@Test
	public void testGetSubjsOnPredLit() {
		Assert.assertEquals(1, this.helper.getSubjsOnPredLit(DublinCore.TITLE_PROPERTY_NAME, "My New Document").size());
	}


	/**
	 */
	@Test
	public void testGetRessOnPredSubjGetSubjsOnPredRes() {
		Assert.assertEquals(1, this.helper.getSubjsOnPredRes(RDF.TYPE, "http://weblab-project.org/core/model/class/Document").size());
	}


	/**
	 * 
	 */
	@Test
	public void testGetPredsOnSubj() {
		final Set<String> predicates = this.helper.getPredsOnSubj(this.res.getUri());
		Assert.assertEquals(4, predicates.size());
		Assert.assertTrue(predicates.contains(DublinCore.TITLE_PROPERTY_NAME));
		Assert.assertTrue(predicates.contains(DublinCore.CREATOR_PROPERTY_NAME));
		Assert.assertTrue(predicates.contains(DublinCore.DATE_PROPERTY_NAME));
	}


	/**
	 * 
	 */
	@Test
	public void testHasLitStat() {
		Assert.assertTrue(this.helper.hasLitStat(this.res.getUri(), DublinCore.DATE_PROPERTY_NAME, "2008-06-25T07:00:30+0200"));
		Assert.assertFalse(this.helper.hasLitStat(this.res.getUri(), DublinCore.DATE_PROPERTY_NAME, "2008-06XXX:00:30"));
		Assert.assertFalse(this.helper.hasLitStat(this.res.getUri() + "sdsdsdf", "http://purl.org/dc/terms/created", "2008-06-25T07:00:30"));
		Assert.assertFalse(this.helper.hasLitStat(this.res.getUri(), "http://pdc/terms/created", "2008-06-25T07:00:30"));
	}
}
