/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl;

import java.io.File;
import java.util.HashMap;
import java.util.Set;

import junit.framework.Assert;

import org.junit.Before;
import org.junit.Test;
import org.ow2.weblab.core.extended.factory.AnnotationFactory;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.util.PoKUtil;
import org.ow2.weblab.core.helper.PoKHelperExtended;
import org.ow2.weblab.core.helper.RDFHelperFactory;
import org.ow2.weblab.core.model.Annotation;

/**
 * @author ymombrun
 * @date 6 oct. 08
 * @todo comment
 */
@Deprecated
public class TestJenaWithReifiedStatements {


	PoKHelperExtended ahe;


	@Before
	public void setUp() throws Exception {
		final Annotation annot = new WebLabMarshaller().unmarshal(new File("src/test/resources/annot.xml"), Annotation.class);
		this.ahe = RDFHelperFactory.getPoKHelperExtended(annot);
		System.out.println("End construct");
	}


	/**
	 */
	@Test
	public void testCreateReif() {
		this.ahe.setPoK(AnnotationFactory.createAndLinkAnnotation(this.ahe.getPoK()));
		this.ahe.setAutoCommitMode(false);
		this.ahe.createLitStatReif("weblab://mySubj", "http://refers.to/property", "MyLit", new HashMap<String, String>(), new HashMap<String, String>(),
				new HashMap<String, String>(), "weblab://myUri/12/shj/stat#22");
		String data = PoKUtil.getPoKData(this.ahe.getPoK());
		if ((data.indexOf('>') != -1) && (data.indexOf('<') != -1)) {
			Assert.assertEquals("Nothing between begin and end of rdf:RDF", "", data.substring(data.indexOf('>') + 1, data.lastIndexOf('<')).trim());
		}

		this.ahe.commit();
		data = PoKUtil.getPoKData(this.ahe.getPoK());
		Assert.assertNotSame("Something between begin and end of rdf:RDF", "", data.substring(data.indexOf('>') + 1, data.lastIndexOf('<')).trim());


		this.ahe.removeStatsWithPred("http://refers.to/property");
		this.ahe.commit();
		data = PoKUtil.getPoKData(this.ahe.getPoK());
		if (data.indexOf('>') < data.lastIndexOf('<')) {
			// if it's not an autoclose description tag
			Assert.assertEquals("Nothing between begin and end of rdf:RDF", "", data.substring(data.indexOf('>') + 1, data.lastIndexOf('<')).trim());
		}
	}


	/**
	 */
	@Test
	public void testGetReifsStats() {

		Assert.assertEquals("Number of anonymous reified statements.", 2, this.ahe.getAnonReifStats().size());

		for (final String statId : this.ahe.getAnonReifStats()) {
			Assert.assertNull("None is anonymous", this.ahe.getAnonResOfAnonReifStat(statId));
			final String uri = this.ahe.getResOfAnonReifStat(statId);
			if (uri == null) {
				final String literal = this.ahe.getLitOfAnonReifStat(statId);
				Assert.assertNotNull("Literal shall not be null", literal);
				Assert.assertTrue("Should end by 4", literal.endsWith("4"));
				final String subj = this.ahe.getSubjOfAnonReifStat(statId);
				Assert.assertNotNull(subj);
				Assert.assertTrue(subj.endsWith("4"));
				Assert.assertNull(this.ahe.getAnonSubjOfAnonReifStat(statId));
				final String pred = this.ahe.getPredOfAnonReifStat(statId);
				Assert.assertNotNull(pred);
				Assert.assertTrue(pred.endsWith("4"));

			} else {
				Assert.assertTrue("Should end by 3", uri.endsWith("3"));
				final String subj = this.ahe.getSubjOfAnonReifStat(statId);
				Assert.assertNotNull(subj);
				Assert.assertTrue(subj.endsWith("3"));
				Assert.assertNull(this.ahe.getAnonSubjOfAnonReifStat(statId));
				final String pred = this.ahe.getPredOfAnonReifStat(statId);
				Assert.assertNotNull(pred);
				Assert.assertTrue(pred.endsWith("3"));
			}
		}

		Assert.assertEquals("Number of named reified statements.", 2, this.ahe.getReifStats().size());

		for (final String statUri : this.ahe.getReifStats()) {
			Assert.assertNull("None is anonymous", this.ahe.getAnonResOnReifStat(statUri));
			final String uri = this.ahe.getResOfReifStat(statUri);
			if (uri == null) {
				final String literal = this.ahe.getLitOfReifStat(statUri);
				Assert.assertNotNull("Literal shall not be null", literal);
				Assert.assertTrue("Should end by 2", literal.endsWith("2"));
				final String subj = this.ahe.getSubjOfReifStat(statUri);
				Assert.assertNotNull(subj);
				Assert.assertTrue(subj.endsWith("2"));
				Assert.assertNull(this.ahe.getAnonSubjOfAnonReifStat(statUri));
				final String pred = this.ahe.getPredOfReifStat(statUri);
				Assert.assertNotNull(pred);
				Assert.assertTrue(pred.endsWith("2"));
			} else {
				Assert.assertTrue("Should end by 1", uri.endsWith("1"));
				final String subj = this.ahe.getSubjOfReifStat(statUri);
				Assert.assertNotNull(subj);
				Assert.assertTrue(subj.endsWith("1"));
				Assert.assertNull(this.ahe.getAnonSubjOfReifStat(statUri));
				final String pred = this.ahe.getPredOfReifStat(statUri);
				Assert.assertNotNull(pred);
				Assert.assertTrue(pred.endsWith("1"));
			}
		}

		final String statUri = "weblab://myStatementUri#1";
		final String uriSubj = this.ahe.getSubjOfReifStat(statUri);
		final String uriObj = this.ahe.getResOfReifStat(statUri);
		final String uriPred = this.ahe.getPredOfReifStat(statUri);
		final Set<String> preds = this.ahe.getPredsOnResStatReif(uriSubj, uriPred, uriObj);
		Assert.assertNotNull(preds);
		Assert.assertEquals(2, preds.size());
		for (final String uriReifPred : preds) {
			if (uriReifPred.endsWith("test")) {
				Assert.assertEquals(2, this.ahe.getRessOnPredResStatReif(uriSubj, uriPred, uriObj, uriReifPred).size());
				for (final String uri : this.ahe.getRessOnPredResStatReif(uriSubj, uriPred, uriObj, uriReifPred)) {
					Assert.assertTrue(uri.endsWith("1"));
					Assert.assertTrue(uri.startsWith("weblab"));
				}
			} else if (uriReifPred.endsWith("test1")) {
				Assert.assertEquals(1, this.ahe.getLitsOnPredResStatReif(uriSubj, uriPred, uriObj, uriReifPred).size());
				for (final String lit : this.ahe.getLitsOnPredResStatReif(uriSubj, uriPred, uriObj, uriReifPred)) {
					Assert.assertTrue(lit.endsWith("1"));
					Assert.assertFalse(lit.startsWith("weblab"));
				}
			} else {
				Assert.fail();
			}
		}
		int count = 0;
		for (final String statId : this.ahe.getAnonReifStats()) {
			for (final String pred : this.ahe.getPredsOnAnonStatReif(statId)) {
				count += this.ahe.getRessOnPredAnonStatReif(statId, pred).size();
				count += this.ahe.getAnonRessOnPredAnonStatReif(statId, pred).size();
				count += this.ahe.getLitsOnPredAnonStatReif(statId, pred).size();
			}
		}
		for (final String statUri2 : this.ahe.getReifStats()) {
			for (final String pred : this.ahe.getPredsOnStatReif(statUri2)) {
				count += this.ahe.getRessOnPredStatReif(statUri2, pred).size();
				count += this.ahe.getAnonRessOnPredStatReif(statUri2, pred).size();
				count += this.ahe.getLitsOnPredStatReif(statUri2, pred).size();
			}
		}
		Assert.assertEquals("4 values on the various statements.", 4, count);
	}


	/**
	 */
	@Test
	public void testRemoveReifStat() {
		Assert.assertEquals("Number of anonymous reified statements.", 2, this.ahe.getAnonReifStats().size());
		Assert.assertEquals("Number of named reified statements.", 2, this.ahe.getReifStats().size());
		this.ahe.setAutoCommitMode(false);
		for (final String statUri : this.ahe.getReifStats()) {
			this.ahe.removeReifStat(statUri);
		}
		Assert.assertEquals("Number of anonymous reified statements.", 2, this.ahe.getAnonReifStats().size());
		Assert.assertEquals("Number of named reified statements.", 0, this.ahe.getReifStats().size());
		for (final String statId : this.ahe.getAnonReifStats()) {
			this.ahe.removeAnonReifStat(statId);
		}
		Assert.assertEquals("Number of anonymous reified statements.", 0, this.ahe.getAnonReifStats().size());
		Assert.assertEquals("Number of named reified statements.", 0, this.ahe.getReifStats().size());

		String data = PoKUtil.getPoKData(this.ahe.getPoK());
		Assert.assertNotSame("Something between begin and end of rdf:RDF", "", data.substring(data.indexOf('>') + 1, data.lastIndexOf('<')).trim());
		this.ahe.commit();

		data = PoKUtil.getPoKData(this.ahe.getPoK());

		if (data.indexOf('>') < data.lastIndexOf('<')) {
			// if it's not an autoclose description tag
			Assert.assertEquals("Nothing between begin and end of rdf:RDF", "", data.substring(data.indexOf('>') + 1, data.lastIndexOf('<')).trim());
		}

	}


}
