package org.ow2.weblab.core.helpers.samples;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.Date;

import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.factory.MediaUnitFactory;
import org.ow2.weblab.core.extended.factory.ResourceFactory;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.Text;
import org.ow2.weblab.core.model.processing.WProcessingAnnotator;
import org.purl.dc.elements.DublinCoreAnnotator;

public class DocumentCreator {

	public static Document createSimpleDocumentWithSmallEnTexts() throws WebLabCheckedException {
		/*
		 * Document creation. Use of ResourceFactory in extended.jar Arguments
		 * are the id the resource creator, id of the resource given the
		 * creator's knowledge of the world, class (extending resource). The
		 * first two parameters are used to generate a unique URI (according to
		 * the creator's knowledge of the world...)
		 */
		final Document doc = ResourceFactory.createResource("test", "d-0", Document.class);

		/*
		 * Creation of a Text MediaUnit inside the Document. With a unique based
		 * on the one of the Document.
		 */
		final Text introduction = MediaUnitFactory.createAndLinkMediaUnit(doc, Text.class);

		// Add the text content inside the mediaUnit.
		introduction.setContent("This is the introduction");

		// Adding more texts
		final Text section = MediaUnitFactory.createAndLinkMediaUnit(doc, Text.class);
		section.setContent("First section\nThis is a text...");
		final Text conclusion = MediaUnitFactory.createAndLinkMediaUnit(doc, Text.class);
		conclusion.setContent("Conclusion\nThis is a versy simple example.");

		return doc;
	}

	public static Document createSimpleDocumentWithBasicMeta() throws WebLabCheckedException {
		final Document doc = ResourceFactory.createResource("test", "d" + System.currentTimeMillis(), Document.class);

		// Adding basic metadata on the document
		WProcessingAnnotator wpa = new WProcessingAnnotator(doc);
		wpa.writeGatheringDate(new Date(System.currentTimeMillis() - 1000 * 3600)); // fake
																					// date
		try {
			wpa.writeProducedBy(new URI("weblab://helpers/samples/DocumentCreator"));
		} catch (URISyntaxException e) {
			throw new WebLabCheckedException("Invalid URI for wlp:producedBy properties.", e);
		}
		return doc;
	}

	public static Document createDocumentWithText(String text, String twoLetterLangCode) throws WebLabCheckedException {
		final Document doc = createSimpleDocumentWithBasicMeta();

		Text t = MediaUnitFactory.createAndLinkMediaUnit(doc, Text.class);
		t.setContent(text);

		DublinCoreAnnotator dca = new DublinCoreAnnotator(t);
		dca.writeLanguage(twoLetterLangCode);

		return doc;
	}

	public static Document createDocWithDeutsch() throws WebLabCheckedException {
		return createDocumentWithText("es gibt' \ndas ist'ein klein haus", "de");
	}

	public static Document createDocWithSpanish() throws WebLabCheckedException {
		Document doc = createDocumentWithText(
				"Un dirigible es un aerostato autopropulsado y con capacidad de maniobra para ser manejado como una aeronave. La sustentación aerostática se logra mediante depósitos llenos de un gas de menor densidad a la atmósfera circundante. Difiere de la sustentación aerodinámica, obtenida mediante el movimiento rápido de un perfil alar, como en el ala de un aeroplano o las aspas de un helicóptero.\n"
						+ "Fue el primer artefacto volador capaz de ser controlado en un vuelo largo. Su uso principal ocurrió aproximadamente entre 1900 y la década de 1930: para disminuir paulatinamente cuando sus capacidades fueron superadas por la de los aeroplanos, y además, después de sufrir varios accidentes de relevancia, el más notable de los cuales fue sin duda el incendio del Hindenburg. Actualmente se los utiliza en una serie de aplicaciones secundarias, especialmente publicidad.",
				"es");
		DublinCoreAnnotator dca = new DublinCoreAnnotator(doc);
		dca.writeSource("http://es.wikipedia.org/wiki/Dirigible");
		dca.writeTitle("Dirigible");
		return doc;
	}

	public static Document createDocWithGreek() throws WebLabCheckedException {
		Document doc = createDocumentWithText(
				"Η λέξη κρυπτογραφία προέρχεται από τα συνθετικά \"κρυπτός\" + \"γράφω\" και είναι ένας επιστημονικός κλάδος που ασχολείται με την μελέτη, την ανάπτυξη και την χρήση τεχνικών κρυπτογράφησης και αποκρυπτογράφησης με σκοπό την απόκρυψη του περιεχομένου των μηνυμάτων.\n\n "
						+ "Η κρυπτογραφία είναι ένας κλάδος της επιστήμης της κρυπτολογίας, η οποία ασχολείται με την μελέτη της ασφαλούς επικοινωνίας. Ο κύριος στόχος της είναι να παρέχει μηχανισμούς για 2 ή περισσότερα μέλη να επικοινωνήσουν χωρίς κάποιος άλλος να είναι ικανός να διαβάζει την πληροφορία εκτός από τα μέλη. Η λέξη κρυπτολογία αποτελείται από την ελληνική λέξη \"κρυπτός\" και την λέξη \"λόγος\" και χωρίζεται σε δύο κλάδους: Την Κρυπτογραφία και την Κρυπτανάλυση με παρεμφερή κλάδο την Στεγανογραφία και αντίστοιχα την Στεγανοανάλυση.",
				"es");
		DublinCoreAnnotator dca = new DublinCoreAnnotator(doc);
		dca.writeSource("http://el.wikipedia.org/wiki/%CE%9A%CF%81%CF%85%CF%80%CF%84%CE%BF%CE%B3%CF%81%CE%B1%CF%86%CE%AF%CE%B1");
		dca.writeTitle("Κρυπτογραφία");
		return doc;
	}
}
